@@ -7,12 +7,10 @@ use owo_colors::OwoColorize;
 use tracing::error;
 
 use crate::cli::ExitStatus;
-use crate::fs::Simplified;
 use crate::printer::Printer;
-use crate::store::{CacheBucket, STORE};
+use crate::store::{CacheBucket, Store};
 
-pub(crate) fn clean(printer: Printer) -> Result<ExitStatus> {
-    let store = STORE.as_ref()?;
+pub(crate) fn clean(store: &Store, printer: Printer) -> Result<ExitStatus> {
     if !store.path().exists() {
         writeln!(printer.stdout(), "Nothing to clean")?;
         return Ok(ExitStatus::Success);
@@ -26,7 +24,7 @@ pub(crate) fn clean(printer: Printer) -> Result<ExitStatus> {
     writeln!(
         printer.stdout(),
         "Cleaned `{}`",
-        store.path().user_display().cyan()
+        store.path().display().cyan()
     )?;
 
     Ok(ExitStatus::Success)
