@@ -7,7 +7,7 @@ use anstream::eprintln;
 use anyhow::Result;
 use owo_colors::OwoColorize;
 
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::cli::{self, ExitStatus, RunArgs};
 use crate::config::HookType;
@@ -120,6 +120,7 @@ pub(crate) async fn hook_impl(
         vec![],
         false,
         false,
+        run_args.fail_fast,
         false,
         false,
         run_args.extra,
