@@ -3,15 +3,17 @@ use std::io::Write;
 use std::path::{Path, PathBuf};
 use std::sync::Arc;
 
-use anyhow::Result;
+use anyhow::{Context, Result};
 use bstr::ByteSlice;
 use owo_colors::OwoColorize;
+use prek_consts::{ALT_CONFIG_FILE, CONFIG_FILE};
 use same_file::is_same_file;
 
 use crate::cli::reporter::{HookInitReporter, HookInstallReporter};
 use crate::cli::run;
 use crate::cli::run::{SelectorSource, Selectors};
 use crate::cli::{ExitStatus, HookType};
+use crate::config::load_config;
 use crate::fs::{CWD, Simplified};
 use crate::git::{GIT_ROOT, git_cmd};
 use crate::printer::Printer;
@@ -35,13 +37,14 @@ pub(crate) async fn install(
 ) -> Result<ExitStatus> {
     if git_dir.is_none() && git::has_hooks_path_set().await? {
         anyhow::bail!(
-            "Cowardly refusing to install hooks with `core.hooksPath` set.\nhint: `{}` to fix this",
-            "git config --unset-all core.hooksPath".cyan()
+            "Cowardly refusing to install hooks with `core.hooksPath` set.\nhint: Run these commands to remove core.hooksPath:\nhint:   {}\nhint:   {}",
+            "git config --unset-all --local core.hooksPath".cyan(),
+            "git config --unset-all --global core.hooksPath".cyan()
         );
     }
 
     let project = Project::discover(config.as_deref(), &CWD).ok();
-    let hook_types = get_hook_types(project.as_ref(), hook_types);
+    let hook_types = get_hook_types(hook_types, project.as_ref(), config.as_deref());
 
     let hooks_path = if let Some(dir) = git_dir {
         dir.join("hooks")
@@ -94,7 +97,10 @@ pub(crate) async fn install_hooks(
     let reporter = HookInitReporter::from(printer);
     let _lock = store.lock_async().await?;
 
-    let hooks = workspace.init_hooks(store, Some(&reporter)).await?;
+    let hooks = workspace
+        .init_hooks(store, Some(&reporter))
+        .await
+        .context("Failed to init hooks")?;
     let filtered_hooks: Vec<_> = hooks
         .into_iter()
         .filter(|h| selectors.matches_hook(h))
@@ -107,19 +113,33 @@ pub(crate) async fn install_hooks(
     Ok(ExitStatus::Success)
 }
 
-fn get_hook_types(project: Option<&Project>, hook_types: Vec<HookType>) -> Vec<HookType> {
-    let mut hook_types = if hook_types.is_empty() {
-        if let Some(project) = project {
-            project
-                .config()
-                .default_install_hook_types
-                .clone()
-                .unwrap_or_default()
-        } else {
-            vec![]
-        }
+fn get_hook_types(
+    mut hook_types: Vec<HookType>,
+    project: Option<&Project>,
+    config: Option<&Path>,
+) -> Vec<HookType> {
+    if !hook_types.is_empty() {
+        return hook_types;
+    }
+
+    hook_types = if let Some(project) = project {
+        project
+            .config()
+            .default_install_hook_types
+            .clone()
+            .unwrap_or_default()
     } else {
-        hook_types
+        let fallbacks = [CONFIG_FILE, ALT_CONFIG_FILE]
+            .iter()
+            .map(Path::new)
+            .filter(|p| p.exists());
+        config
+            .into_iter()
+            .chain(fallbacks)
+            .next()
+            .and_then(|p| load_config(p).ok())
+            .and_then(|cfg| cfg.default_install_hook_types.clone())
+            .unwrap_or_default()
     };
     if hook_types.is_empty() {
         hook_types = vec![HookType::PreCommit];
@@ -153,7 +173,7 @@ fn install_hook_script(
                 fs_err::rename(&hook_path, &legacy_path)?;
                 writeln!(
                     printer.stdout(),
-                    "Hook already exists at `{}`, move it to `{}`",
+                    "Hook already exists at `{}`, moved it to `{}`",
                     hook_path.user_display().cyan(),
                     legacy_path.user_display().yellow()
                 )?;
@@ -192,31 +212,36 @@ fn install_hook_script(
 
     args.push(format!("--hook-type={}", hook_type.as_str()));
 
+    let mut hint = format!("prek installed at `{}`", hook_path.user_display().cyan());
+
     // Prefer explicit config path if given (non-workspace mode).
     // Otherwise, use the config path from the discovered project (workspace mode).
     // If neither is available, don't pass a config path (let prek find it). In this case,
     // we're different with `pre-commit` which always sets `--config=.pre-commit-config.yaml`.
-    let target_info = if let Some(config) = config {
+    if let Some(config) = config {
         args.push(format!(r#"--config="{}""#, config.display()));
-        format!(" with specified config `{}`", config.display().cyan())
+
+        write!(hint, " with specified config `{}`", config.display().cyan())?;
     } else if let Some(project) = project {
+        let git_root = GIT_ROOT.as_ref()?;
         let project_path = project.path();
-        let relative_path = project_path
-            .strip_prefix(GIT_ROOT.as_ref()?)
-            .unwrap_or(project_path);
+        let relative_path = project_path.strip_prefix(git_root).unwrap_or(project_path);
         if !relative_path.as_os_str().is_empty() {
             args.push(format!(r#"--cd="{}""#, relative_path.display()));
         }
 
-        if project_path == GIT_ROOT.as_ref()? {
-            String::new()
-        } else {
-            // Show workspace path if it's not the root project.
-            format!(" for workspace `{}`", project_path.display().cyan())
+        // Show workspace path if it's not the root project.
+        if project_path != git_root {
+            writeln!(hint, " for workspace `{}`", project_path.display().cyan())?;
+            write!(
+                hint,
+                "\n{} this hook installed for `{}` only; run `prek install` from `{}` to install for the entire repo.",
+                "hint:".bold().yellow(),
+                project_path.display().cyan(),
+                git_root.display().cyan()
+            )?;
         }
-    } else {
-        String::new()
-    };
+    }
 
     if skip_on_missing_config {
         args.push("--skip-on-missing-config".to_string());
@@ -225,7 +250,7 @@ fn install_hook_script(
     args.push(format!("--script-version={CUR_SCRIPT_VERSION}"));
 
     let prek = std::env::current_exe()?;
-    let prek = prek.simplified().display().to_string();
+    let prek = prek.simplified_display().to_string();
     let hook_script = HOOK_TMPL
         .replace(
             "[SHEBANG]",
@@ -254,11 +279,7 @@ fn install_hook_script(
         fs_err::set_permissions(&hook_path, perms)?;
     }
 
-    writeln!(
-        printer.stdout(),
-        "prek installed at `{}`{target_info}",
-        hook_path.user_display().cyan(),
-    )?;
+    writeln!(printer.stdout(), "{hint}")?;
 
     Ok(())
 }
@@ -312,9 +333,9 @@ pub(crate) async fn uninstall(
     printer: Printer,
 ) -> Result<ExitStatus> {
     let project = Project::discover(config.as_deref(), &CWD).ok();
+    let hooks_path = git::get_git_common_dir().await?.join("hooks");
 
-    for hook_type in get_hook_types(project.as_ref(), hook_types) {
-        let hooks_path = git::get_git_common_dir().await?.join("hooks");
+    for hook_type in get_hook_types(hook_types, project.as_ref(), config.as_deref()) {
         let hook_path = hooks_path.join(hook_type.as_str());
         let legacy_path = hooks_path.join(format!("{}.legacy", hook_type.as_str()));
 
