@@ -1,6 +1,7 @@
 use std::fmt::Write;
 use std::path::PathBuf;
 
+use anyhow::Context;
 use clap::ValueEnum;
 use owo_colors::OwoColorize;
 use serde::Serialize;
@@ -45,7 +46,10 @@ pub(crate) async fn list(
 
     let reporter = HookInitReporter::from(printer);
     let lock = store.lock_async().await?;
-    let hooks = workspace.init_hooks(store, Some(&reporter)).await?;
+    let hooks = workspace
+        .init_hooks(store, Some(&reporter))
+        .await
+        .context("Failed to init hooks")?;
 
     drop(lock);
 
@@ -113,7 +117,7 @@ pub(crate) async fn list(
             let serializable_hooks: Vec<_> = filtered_hooks
                 .into_iter()
                 .map(|h| {
-                    let id = h.id.to_string();
+                    let id = h.id.clone();
                     let full_id = h.full_id();
                     let stages = match h.stages {
                         hook::Stages::All => Stage::value_variants().to_vec(),
