@@ -8,8 +8,8 @@ use clap::{ArgAction, Args, Parser, Subcommand, ValueHint};
 use clap_complete::engine::ArgValueCompleter;
 use serde::{Deserialize, Serialize};
 
-use constants::CONFIG_FILE;
-use constants::env_vars::EnvVars;
+use prek_consts::CONFIG_FILE;
+use prek_consts::env_vars::EnvVars;
 
 use crate::config::{HookType, Language, Stage};
 
@@ -82,16 +82,6 @@ pub enum ColorChoice {
     Never,
 }
 
-impl From<ColorChoice> for anstream::ColorChoice {
-    fn from(value: ColorChoice) -> Self {
-        match value {
-            ColorChoice::Auto => Self::Auto,
-            ColorChoice::Always => Self::Always,
-            ColorChoice::Never => Self::Never,
-        }
-    }
-}
-
 const STYLES: Styles = Styles::styled()
     .header(AnsiColor::Green.on_default().effects(Effects::BOLD))
     .usage(AnsiColor::Green.on_default().effects(Effects::BOLD))
@@ -450,6 +440,10 @@ pub(crate) struct RunArgs {
     #[arg(long)]
     pub(crate) show_diff_on_failure: bool,
 
+    /// Stop running hooks after the first failure.
+    #[arg(long)]
+    pub(crate) fail_fast: bool,
+
     /// Do not run the hooks, but print the hooks that would have been run.
     #[arg(long)]
     pub(crate) dry_run: bool,
@@ -682,8 +676,8 @@ mod tests {
     use crate::cli::Cli;
     use anyhow::{Result, bail};
     use clap::{Command, CommandFactory};
-    use constants::env_vars::EnvVars;
     use itertools::Itertools;
+    use prek_consts::env_vars::EnvVars;
     use pretty_assertions::StrComparison;
     use std::cmp::max;
     use std::path::PathBuf;
