@@ -1,19 +1,19 @@
 use std::path::{Path, PathBuf};
 
-use anyhow::Result;
+use anyhow::{Context, Result};
 use fancy_regex::Regex;
 use itertools::{Either, Itertools};
+use path_clean::PathClean;
 use rayon::iter::{IntoParallelRefIterator, ParallelBridge, ParallelIterator};
 use rustc_hash::FxHashSet;
-use tracing::{debug, error};
+use tracing::{debug, error, instrument};
 
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::config::Stage;
-use crate::fs::normalize_path;
 use crate::git::GIT_ROOT;
 use crate::hook::Hook;
-use crate::identify::tags_from_path;
+use crate::identify::{TagSet, tags_from_path};
 use crate::workspace::Project;
 use crate::{fs, git, warn_user};
 
@@ -66,18 +66,14 @@ impl<'a> FileTagFilter<'a> {
         }
     }
 
-    pub(crate) fn filter(&self, file_types: &[&str]) -> bool {
-        if !self.all.is_empty() && !self.all.iter().all(|t| file_types.contains(&t.as_str())) {
+    pub(crate) fn filter(&self, file_types: &TagSet) -> bool {
+        if !self.all.is_empty() && !self.all.iter().all(|t| file_types.contains(t.as_str())) {
             return false;
         }
-        if !self.any.is_empty() && !self.any.iter().any(|t| file_types.contains(&t.as_str())) {
+        if !self.any.is_empty() && !self.any.iter().any(|t| file_types.contains(t.as_str())) {
             return false;
         }
-        if self
-            .exclude
-            .iter()
-            .any(|t| file_types.contains(&t.as_str()))
-        {
+        if self.exclude.iter().any(|t| file_types.contains(t.as_str())) {
             return false;
         }
         true
@@ -95,6 +91,7 @@ pub(crate) struct FileFilter<'a> {
 
 impl<'a> FileFilter<'a> {
     // Here, `filenames` are paths relative to the workspace root.
+    #[instrument(level = "trace", skip_all, fields(project = %project))]
     pub(crate) fn for_project<I>(filenames: I, project: &'a Project) -> Self
     where
         I: Iterator<Item = &'a PathBuf> + Send,
@@ -152,6 +149,7 @@ impl<'a> FileFilter<'a> {
     }
 
     /// Filter filenames by file patterns and tags for a specific hook.
+    #[instrument(level = "trace", skip_all, fields(hook = ?hook.id))]
     pub(crate) fn for_hook(&self, hook: &Hook) -> Vec<&Path> {
         // Filter by hook `files` and `exclude` patterns.
         let filter = FilenameFilter::for_hook(hook);
@@ -207,7 +205,7 @@ impl CollectOptions {
 
 /// Get all filenames to run hooks on.
 /// Returns a list of file paths relative to the workspace root.
-#[allow(clippy::too_many_arguments)]
+#[instrument(level = "trace", skip_all)]
 pub(crate) async fn collect_files(root: &Path, opts: CollectOptions) -> Result<Vec<PathBuf>> {
     let CollectOptions {
         hook_stage,
@@ -222,7 +220,13 @@ pub(crate) async fn collect_files(root: &Path, opts: CollectOptions) -> Result<V
     let git_root = GIT_ROOT.as_ref()?;
 
     // The workspace root relative to the git root.
-    let relative_root = root.strip_prefix(git_root)?;
+    let relative_root = root.strip_prefix(git_root).with_context(|| {
+        format!(
+            "Workspace root `{}` is not under git root `{}`",
+            root.display(),
+            git_root.display()
+        )
+    })?;
 
     let filenames = collect_files_from_args(
         git_root,
@@ -244,7 +248,7 @@ pub(crate) async fn collect_files(root: &Path, opts: CollectOptions) -> Result<V
             // Only keep files under the workspace root.
             filename
                 .strip_prefix(relative_root)
-                .map(|p| normalize_path(p.to_path_buf()))
+                .map(|p| fs::normalize_path(p.to_path_buf()))
                 .ok()
         })
         .collect::<Vec<_>>();
@@ -258,7 +262,8 @@ pub(crate) async fn collect_files(root: &Path, opts: CollectOptions) -> Result<V
 }
 
 fn adjust_relative_path(path: &str, new_cwd: &Path) -> Result<PathBuf, std::io::Error> {
-    fs::relative_to(std::path::absolute(path)?, new_cwd)
+    let absolute = std::path::absolute(path)?.clean();
+    fs::relative_to(absolute, new_cwd)
 }
 
 /// Collect files to run hooks on.
@@ -315,12 +320,12 @@ async fn collect_files_from_args(
         if !non_exists.is_empty() {
             if non_exists.len() == 1 {
                 warn_user!(
-                    "This file does not exist, it will be ignored: `{}`",
+                    "This file does not exist and will be ignored: `{}`",
                     non_exists[0]
                 );
             } else {
                 warn_user!(
-                    "These files do not exist, they will be ignored: `{}`",
+                    "These files do not exist and will be ignored: `{}`",
                     non_exists.join(", ")
                 );
             }
@@ -328,14 +333,14 @@ async fn collect_files_from_args(
 
         let mut exists = exists
             .into_iter()
-            .map(|filename| adjust_relative_path(&filename, git_root).map(normalize_path))
+            .map(|filename| adjust_relative_path(&filename, git_root).map(fs::normalize_path))
             .collect::<Result<FxHashSet<_>, _>>()?;
 
         for dir in directories {
             let dir = adjust_relative_path(&dir, git_root)?;
             let dir_files = git::ls_files(git_root, &dir).await?;
             for file in dir_files {
-                let file = normalize_path(file);
+                let file = fs::normalize_path(file);
                 exists.insert(file);
             }
         }
