@@ -1,7 +1,9 @@
 pub(crate) use filter::{CollectOptions, FileFilter, collect_files};
 pub(crate) use run::{install_hooks, run};
+pub(crate) use selector::{SelectorSource, Selectors};
 
 mod filter;
 mod keeper;
 #[allow(clippy::module_inception)]
 mod run;
+mod selector;
