@@ -15,7 +15,7 @@ use tokio::sync::{OnceCell, Semaphore};
 use tracing::{debug, trace, warn};
 use unicode_width::UnicodeWidthStr;
 
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::cli::reporter::{HookInitReporter, HookInstallReporter};
 use crate::cli::run::keeper::WorkTreeKeeper;
@@ -23,13 +23,13 @@ use crate::cli::run::{CollectOptions, FileFilter, Selectors, collect_files};
 use crate::cli::{ExitStatus, RunExtraArgs};
 use crate::config::{Language, Stage};
 use crate::fs::CWD;
-use crate::git;
 use crate::git::GIT_ROOT;
-use crate::hook::{Hook, InstallInfo, InstalledHook};
+use crate::hook::{Hook, InstallInfo, InstalledHook, Repo};
 use crate::printer::{Printer, Stdout};
 use crate::run::{CONCURRENCY, USE_COLOR};
 use crate::store::Store;
 use crate::workspace::{Project, Workspace};
+use crate::{git, warn_user};
 
 #[allow(clippy::too_many_arguments, clippy::fn_params_excessive_bools)]
 pub(crate) async fn run(
@@ -45,6 +45,7 @@ pub(crate) async fn run(
     directories: Vec<String>,
     last_commit: bool,
     show_diff_on_failure: bool,
+    fail_fast: bool,
     dry_run: bool,
     refresh: bool,
     extra_args: RunExtraArgs,
@@ -87,7 +88,10 @@ pub(crate) async fn run(
     let reporter = HookInitReporter::from(printer);
     let lock = store.lock_async().await?;
 
-    let hooks = workspace.init_hooks(store, Some(&reporter)).await?;
+    let hooks = workspace
+        .init_hooks(store, Some(&reporter))
+        .await
+        .context("Failed to init hooks")?;
     let filtered_hooks: Vec<_> = hooks
         .into_iter()
         .filter(|h| selectors.matches_hook(h))
@@ -102,6 +106,15 @@ pub(crate) async fn run(
             "{}: No hooks found after filtering with the given selectors",
             "error".red().bold(),
         )?;
+        if selectors.has_project_selectors() {
+            writeln!(
+                printer.stderr(),
+                "\n{} If you just added new `{}`, try rerun your command with the `{}` flag to rescan the workspace.",
+                "hint:".bold().yellow(),
+                ".pre-commit-config.yaml".cyan(),
+                "--refresh".cyan(),
+            )?;
+        }
         return Ok(ExitStatus::Failure);
     }
 
@@ -133,7 +146,11 @@ pub(crate) async fn run(
     // Clear any unstaged changes from the git working directory.
     let mut _guard = None;
     if should_stash {
-        _guard = Some(WorkTreeKeeper::clean(store, workspace.root()).await?);
+        _guard = Some(
+            WorkTreeKeeper::clean(store, workspace.root())
+                .await
+                .context("Failed to clean work tree")?,
+        );
     }
 
     set_env_vars(from_ref.as_ref(), to_ref.as_ref(), &extra_args);
@@ -150,7 +167,8 @@ pub(crate) async fn run(
             commit_msg_filename: extra_args.commit_msg_filename,
         },
     )
-    .await?;
+    .await
+    .context("Failed to collect files")?;
 
     // Change to the workspace root directory.
     std::env::set_current_dir(workspace.root()).with_context(|| {
@@ -166,6 +184,7 @@ pub(crate) async fn run(
         filenames,
         store,
         show_diff_on_failure,
+        fail_fast,
         dry_run,
         verbose,
         printer,
@@ -178,46 +197,46 @@ fn set_env_vars(from_ref: Option<&String>, to_ref: Option<&String>, args: &RunEx
     unsafe {
         std::env::set_var("PRE_COMMIT", "1");
 
-        if let Some(ref source) = args.prepare_commit_message_source {
-            std::env::set_var("PRE_COMMIT_COMMIT_MSG_SOURCE", source.clone());
+        if let Some(source) = &args.prepare_commit_message_source {
+            std::env::set_var("PRE_COMMIT_COMMIT_MSG_SOURCE", source);
         }
-        if let Some(ref object) = args.commit_object_name {
-            std::env::set_var("PRE_COMMIT_COMMIT_OBJECT_NAME", object.clone());
+        if let Some(object) = &args.commit_object_name {
+            std::env::set_var("PRE_COMMIT_COMMIT_OBJECT_NAME", object);
         }
         if let Some(from_ref) = from_ref {
-            std::env::set_var("PRE_COMMIT_ORIGIN", from_ref.clone());
-            std::env::set_var("PRE_COMMIT_FROM_REF", from_ref.clone());
+            std::env::set_var("PRE_COMMIT_ORIGIN", from_ref);
+            std::env::set_var("PRE_COMMIT_FROM_REF", from_ref);
         }
         if let Some(to_ref) = to_ref {
-            std::env::set_var("PRE_COMMIT_SOURCE", to_ref.clone());
-            std::env::set_var("PRE_COMMIT_TO_REF", to_ref.clone());
+            std::env::set_var("PRE_COMMIT_SOURCE", to_ref);
+            std::env::set_var("PRE_COMMIT_TO_REF", to_ref);
         }
-        if let Some(ref upstream) = args.pre_rebase_upstream {
-            std::env::set_var("PRE_COMMIT_PRE_REBASE_UPSTREAM", upstream.clone());
+        if let Some(upstream) = &args.pre_rebase_upstream {
+            std::env::set_var("PRE_COMMIT_PRE_REBASE_UPSTREAM", upstream);
         }
-        if let Some(ref branch) = args.pre_rebase_branch {
-            std::env::set_var("PRE_COMMIT_PRE_REBASE_BRANCH", branch.clone());
+        if let Some(branch) = &args.pre_rebase_branch {
+            std::env::set_var("PRE_COMMIT_PRE_REBASE_BRANCH", branch);
         }
-        if let Some(ref branch) = args.local_branch {
-            std::env::set_var("PRE_COMMIT_LOCAL_BRANCH", branch.clone());
+        if let Some(branch) = &args.local_branch {
+            std::env::set_var("PRE_COMMIT_LOCAL_BRANCH", branch);
         }
-        if let Some(ref branch) = args.remote_branch {
-            std::env::set_var("PRE_COMMIT_REMOTE_BRANCH", branch.clone());
+        if let Some(branch) = &args.remote_branch {
+            std::env::set_var("PRE_COMMIT_REMOTE_BRANCH", branch);
         }
-        if let Some(ref name) = args.remote_name {
-            std::env::set_var("PRE_COMMIT_REMOTE_NAME", name.clone());
+        if let Some(name) = &args.remote_name {
+            std::env::set_var("PRE_COMMIT_REMOTE_NAME", name);
         }
-        if let Some(ref url) = args.remote_url {
-            std::env::set_var("PRE_COMMIT_REMOTE_URL", url.clone());
+        if let Some(url) = &args.remote_url {
+            std::env::set_var("PRE_COMMIT_REMOTE_URL", url);
         }
-        if let Some(ref checkout) = args.checkout_type {
-            std::env::set_var("PRE_COMMIT_CHECKOUT_TYPE", checkout.clone());
+        if let Some(checkout) = &args.checkout_type {
+            std::env::set_var("PRE_COMMIT_CHECKOUT_TYPE", checkout);
         }
         if args.is_squash_merge {
             std::env::set_var("PRE_COMMIT_SQUASH_MERGE", "1");
         }
-        if let Some(ref command) = args.rewrite_command {
-            std::env::set_var("PRE_COMMIT_REWRITE_COMMAND", command.clone());
+        if let Some(command) = &args.rewrite_command {
+            std::env::set_var("PRE_COMMIT_REWRITE_COMMAND", command);
         }
     }
 }
@@ -285,8 +304,14 @@ pub async fn install_hooks(
     // Group hooks by language to enable parallel installation across different languages.
     let mut hooks_by_language = FxHashMap::default();
     for hook in hooks {
+        let mut language = hook.language;
+        if hook.language == Language::Pygrep {
+            // Treat `pygrep` hooks as `python` hooks for installation purposes.
+            // They share the same installation logic.
+            language = Language::Python;
+        }
         hooks_by_language
-            .entry(hook.language)
+            .entry(language)
             .or_insert_with(Vec::new)
             .push(hook);
     }
@@ -307,6 +332,15 @@ pub async fn install_hooks(
                 let mut newly_installed = Vec::new();
 
                 for hook in hooks {
+                    if matches!(hook.repo(), Repo::Meta { .. } | Repo::Builtin { .. }) {
+                        debug!(
+                            "Hook `{}` is a meta or builtin hook, no installation needed",
+                            &hook
+                        );
+                        hook_envs.push(InstalledHook::NoNeedInstall(hook));
+                        continue;
+                    }
+
                     let mut matched_info = None;
 
                     for env in &newly_installed {
@@ -340,18 +374,17 @@ pub async fn install_hooks(
                     }
 
                     let _permit = semaphore.acquire().await.unwrap();
-                    debug!("No matching environment found for hook `{hook}`, installing...");
 
                     let installed_hook = hook
                         .language
                         .install(hook.clone(), store, reporter)
                         .await
-                        .context(format!("Failed to install hook `{hook}`"))?;
+                        .with_context(|| format!("Failed to install hook `{hook}`"))?;
 
                     installed_hook
                         .mark_as_installed(store)
                         .await
-                        .context(format!("Failed to mark hook `{hook}` as installed"))?;
+                        .with_context(|| format!("Failed to mark hook `{hook}` as installed"))?;
 
                     match &installed_hook {
                         InstalledHook::Installed { info, .. } => {
@@ -522,6 +555,7 @@ async fn run_hooks(
     filenames: Vec<PathBuf>,
     store: &Store,
     show_diff_on_failure: bool,
+    fail_fast: bool,
     dry_run: bool,
     verbose: bool,
     printer: Printer,
@@ -549,6 +583,7 @@ async fn run_hooks(
     let projects_len = project_to_hooks.len();
     let mut first = true;
     let mut file_modified = false;
+    let mut has_unimplemented = false;
 
     // Hooks might modify the files, so they must be run sequentially.
     'outer: for (_, mut hooks) in project_to_hooks {
@@ -566,7 +601,8 @@ async fn run_hooks(
         }
         let mut diff = git::get_diff(project.path()).await?;
 
-        let fail_fast = project.config().fail_fast.unwrap_or(false);
+        // CLI flag overrides config setting
+        let fail_fast = fail_fast || project.config().fail_fast.unwrap_or(false);
 
         let filter = FileFilter::for_project(filenames.iter(), project);
         trace!(
@@ -574,18 +610,28 @@ async fn run_hooks(
             filter.len()
         );
 
-        let mut hook_succeed;
         for hook in hooks {
-            (hook_succeed, diff, file_modified) =
-                run_hook(hook, &filter, store, diff, verbose, dry_run, &printer).await?;
+            let result = run_hook(hook, &filter, store, diff, verbose, dry_run, &printer).await?;
+            diff = result.new_diff;
+            file_modified |= result.file_modified;
+            has_unimplemented |= result.status.is_unimplemented();
 
-            success &= hook_succeed;
+            success &= result.status.as_bool();
             if !success && (fail_fast || hook.fail_fast) {
                 break 'outer;
             }
         }
     }
 
+    if has_unimplemented {
+        warn_user!(
+            "Some hooks were skipped because their languages are unimplemented.\nWe're working hard to support more languages. Check out current support status at {}.",
+            "https://prek.j178.dev/todo/#language-support-status"
+                .cyan()
+                .underline()
+        );
+    }
+
     if !success && show_diff_on_failure && file_modified {
         if EnvVars::is_set(EnvVars::CI) {
             writeln!(
@@ -637,6 +683,33 @@ fn shuffle<T>(filenames: &mut [T]) {
     filenames.shuffle(&mut rng);
 }
 
+enum RunStatus {
+    Success,
+    Failed,
+    Skipped,
+    Unimplemented,
+}
+
+impl RunStatus {
+    fn from_bool(success: bool) -> Self {
+        if success { Self::Success } else { Self::Failed }
+    }
+
+    fn as_bool(&self) -> bool {
+        matches!(self, Self::Success | Self::Skipped | Self::Unimplemented)
+    }
+
+    fn is_unimplemented(&self) -> bool {
+        matches!(self, Self::Unimplemented)
+    }
+}
+
+struct RunResult {
+    status: RunStatus,
+    new_diff: Vec<u8>,
+    file_modified: bool,
+}
+
 async fn run_hook(
     hook: &InstalledHook,
     filter: &FileFilter<'_>,
@@ -645,7 +718,7 @@ async fn run_hook(
     verbose: bool,
     dry_run: bool,
     printer: &StatusPrinter,
-) -> Result<(bool, Vec<u8>, bool)> {
+) -> Result<RunResult> {
     let mut filenames = filter.for_hook(hook);
     trace!(
         "Files for hook `{}` after filtered: {}",
@@ -659,7 +732,11 @@ async fn run_hook(
             StatusPrinter::NO_FILES,
             Style::new().black().on_cyan(),
         )?;
-        return Ok((true, diff, false));
+        return Ok(RunResult {
+            status: RunStatus::Skipped,
+            new_diff: diff,
+            file_modified: false,
+        });
     }
 
     if !Language::supported(hook.language) {
@@ -668,7 +745,11 @@ async fn run_hook(
             StatusPrinter::UNIMPLEMENTED,
             Style::new().black().on_yellow(),
         )?;
-        return Ok((true, diff, false));
+        return Ok(RunResult {
+            status: RunStatus::Unimplemented,
+            new_diff: diff,
+            file_modified: false,
+        });
     }
 
     printer.write_running(&hook.name, false)?;
@@ -701,7 +782,7 @@ async fn run_hook(
         hook.language
             .run(hook, &filenames, store)
             .await
-            .context(format!("Failed to run hook `{hook}`"))?
+            .with_context(|| format!("Failed to run hook `{hook}`"))?
     };
 
     let duration = start.elapsed();
@@ -757,12 +838,16 @@ async fn run_hook(
             } else {
                 writeln!(
                     stdout,
-                    "{}",
-                    textwrap::indent(&String::from_utf8_lossy(output), "  ").dimmed()
+                    "\n{}",
+                    textwrap::indent(&String::from_utf8_lossy(output), "  ")
                 )?;
             }
         }
     }
 
-    Ok((success, new_diff, file_modified))
+    Ok(RunResult {
+        status: RunStatus::from_bool(success),
+        new_diff,
+        file_modified,
+    })
 }
