@@ -7,9 +7,9 @@ use crate::hook::Hook;
 use crate::warn_user;
 
 use anyhow::anyhow;
-use constants::env_vars::EnvVars;
 use itertools::Itertools;
 use path_clean::PathClean;
+use prek_consts::env_vars::EnvVars;
 use rustc_hash::FxHashSet;
 use tracing::trace;
 
@@ -193,6 +193,15 @@ impl Selectors {
         &self.skips
     }
 
+    pub(crate) fn has_project_selectors(&self) -> bool {
+        self.includes.iter().any(|include| {
+            matches!(
+                include.expr,
+                SelectorExpr::ProjectPrefix(_) | SelectorExpr::ProjectHook { .. }
+            )
+        })
+    }
+
     /// Check if a hook matches any of the selection criteria.
     pub(crate) fn matches_hook(&self, hook: &Hook) -> bool {
         let mut usage = self.usage.lock().unwrap();
@@ -472,7 +481,7 @@ pub struct RealFileSystem;
 
 impl FileSystem for RealFileSystem {
     fn absolute<P: AsRef<Path>>(&self, path: P) -> std::io::Result<PathBuf> {
-        std::path::absolute(path)
+        Ok(std::path::absolute(path)?.clean())
     }
 }
 
