@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::collections::HashSet;
 use std::path::{Path, PathBuf};
 use std::process::Stdio;
@@ -5,9 +6,10 @@ use std::str::Utf8Error;
 use std::sync::LazyLock;
 
 use anyhow::Result;
+use path_clean::PathClean;
 use rustc_hash::FxHashSet;
 use tokio::io::{AsyncReadExt, AsyncWriteExt};
-use tracing::{debug, warn};
+use tracing::{debug, instrument, warn};
 
 use crate::process;
 use crate::process::{Cmd, StatusError};
@@ -115,8 +117,9 @@ pub(crate) async fn get_changed_files(
     Ok(zsplit(&output.stdout)?)
 }
 
+#[instrument(level = "trace")]
 pub(crate) async fn ls_files(cwd: &Path, path: &Path) -> Result<Vec<PathBuf>, Error> {
-    let output = git_cmd("get git all files")?
+    let output = git_cmd("git ls-files")?
         .current_dir(cwd)
         .arg("ls-files")
         .arg("-z")
@@ -263,6 +266,7 @@ async fn parse_merge_msg_for_conflicts() -> Result<Vec<PathBuf>, Error> {
     Ok(conflicts)
 }
 
+#[instrument(level = "trace")]
 pub(crate) async fn get_diff(path: &Path) -> Result<Vec<u8>, Error> {
     let output = git_cmd("git diff")?
         .arg("diff")
@@ -293,6 +297,7 @@ pub(crate) async fn write_tree() -> Result<String, Error> {
 }
 
 /// Get the path of the top-level directory of the working tree.
+#[instrument(level = "trace")]
 pub(crate) fn get_root() -> Result<PathBuf, Error> {
     let git = GIT.as_ref().map_err(|&e| Error::GitNotFound(e))?;
     let output = std::process::Command::new(git)
@@ -315,7 +320,22 @@ pub(crate) fn get_root() -> Result<PathBuf, Error> {
 }
 
 pub(crate) async fn init_repo(url: &str, path: &Path) -> Result<(), Error> {
+    let url = if Path::new(url).is_dir() {
+        // If the URL is a local path, convert it to an absolute path
+        Cow::Owned(
+            std::path::absolute(url)?
+                .clean()
+                .to_string_lossy()
+                .to_string(),
+        )
+    } else {
+        Cow::Borrowed(url)
+    };
+
     git_cmd("init git repo")?
+        // Unset `extensions.objectFormat` if set, just follow what hash the remote uses.
+        .arg("-c")
+        .arg("init.defaultObjectFormat=")
         .arg("init")
         .arg("--template=")
         .arg(path)
@@ -329,7 +349,7 @@ pub(crate) async fn init_repo(url: &str, path: &Path) -> Result<(), Error> {
         .arg("remote")
         .arg("add")
         .arg("origin")
-        .arg(url)
+        .arg(&*url)
         .remove_git_env()
         .check(true)
         .output()
@@ -567,3 +587,24 @@ pub(crate) async fn get_parent_commit(commit: &str) -> Result<Option<String>, Er
         Ok(None)
     }
 }
+
+/// Return a list of absolute paths of all git submodules in the repository.
+#[instrument(level = "trace")]
+pub(crate) fn list_submodules(git_root: &Path) -> Result<Vec<PathBuf>, Error> {
+    let git = GIT.as_ref().map_err(|&e| Error::GitNotFound(e))?;
+    let output = std::process::Command::new(git)
+        .current_dir(git_root)
+        .arg("config")
+        .arg("--file")
+        .arg(".gitmodules")
+        .arg("--get-regexp")
+        .arg(r"^submodule\..*\.path$")
+        .output()?;
+
+    Ok(String::from_utf8_lossy(&output.stdout)
+        .trim_ascii()
+        .lines()
+        .filter_map(|line| line.split_whitespace().nth(1))
+        .map(|submodule| git_root.join(submodule))
+        .collect())
+}
