@@ -1,22 +1,21 @@
 use std::ffi::OsStr;
 use std::fmt::{Display, Formatter};
-use std::hash::{Hash, Hasher};
 use std::ops::Deref;
 use std::path::{Path, PathBuf};
 use std::sync::{Arc, OnceLock};
 
 use anyhow::{Context, Result};
 use clap::ValueEnum;
-use constants::MANIFEST_FILE;
-use rand::Rng;
+use prek_consts::MANIFEST_FILE;
 use rustc_hash::{FxBuildHasher, FxHashMap, FxHashSet};
 use serde::{Deserialize, Serialize};
+use tempfile::TempDir;
 use thiserror::Error;
 use tracing::{error, trace};
 
 use crate::config::{
-    self, Config, HookOptions, Language, LocalHook, ManifestHook, MetaHook, RemoteHook, SerdeRegex,
-    Stage, read_manifest,
+    self, BuiltinHook, Config, HookOptions, Language, LocalHook, ManifestHook, MetaHook,
+    RemoteHook, SerdeRegex, Stage, read_manifest,
 };
 use crate::languages::version::LanguageRequest;
 use crate::languages::{extract_metadata_from_entry, resolve_command};
@@ -28,7 +27,7 @@ pub(crate) enum Error {
     #[error(transparent)]
     Config(#[from] config::Error),
 
-    #[error("Hook `{hook}` is invalid")]
+    #[error("Invalid hook `{hook}`")]
     Hook {
         hook: String,
         #[source]
@@ -41,6 +40,9 @@ pub(crate) enum Error {
         #[source]
         error: config::Error,
     },
+
+    #[error("Failed to create directory for hook environment")]
+    TmpDir(#[from] std::io::Error),
 }
 
 #[derive(Debug, Clone)]
@@ -58,13 +60,16 @@ pub(crate) enum Repo {
     Meta {
         hooks: Vec<ManifestHook>,
     },
+    Builtin {
+        hooks: Vec<ManifestHook>,
+    },
 }
 
 impl Repo {
     /// Load the remote repo manifest from the path.
     pub(crate) fn remote(url: String, rev: String, path: PathBuf) -> Result<Self, Error> {
         let manifest = read_manifest(&path.join(MANIFEST_FILE)).map_err(|e| Error::Manifest {
-            repo: url.to_string(),
+            repo: url.clone(),
             error: e,
         })?;
         let hooks = manifest.hooks;
@@ -89,6 +94,13 @@ impl Repo {
         }
     }
 
+    /// Construct a builtin repo.
+    pub(crate) fn builtin(hooks: Vec<BuiltinHook>) -> Self {
+        Self::Builtin {
+            hooks: hooks.into_iter().map(ManifestHook::from).collect(),
+        }
+    }
+
     /// Get the path to the cloned repo if it is a remote repo.
     pub(crate) fn path(&self) -> Option<&Path> {
         match self {
@@ -103,17 +115,19 @@ impl Repo {
             Repo::Remote { hooks, .. } => hooks,
             Repo::Local { hooks } => hooks,
             Repo::Meta { hooks } => hooks,
+            Repo::Builtin { hooks } => hooks,
         };
         hooks.iter().find(|hook| hook.id == id)
     }
 }
 
 impl Display for Repo {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Repo::Remote { url, rev, .. } => write!(f, "{url}@{rev}"),
             Repo::Local { .. } => write!(f, "local"),
             Repo::Meta { .. } => write!(f, "meta"),
+            Repo::Builtin { .. } => write!(f, "builtin"),
         }
     }
 }
@@ -204,36 +218,38 @@ impl HookBuilder {
             .as_ref()
             .map_or(&[][..], |deps| deps.as_slice());
 
-        if !language.supports_dependency() && !additional_dependencies.is_empty() {
-            return Err(Error::Hook {
-                hook: self.config.id.clone(),
-                error: anyhow::anyhow!(
-                    "Hook specified `additional_dependencies` `{}` but the language `{}` does not support installing dependencies for now",
-                    additional_dependencies.join(", "),
-                    language,
-                ),
-            });
+        if !additional_dependencies.is_empty() {
+            if !language.supports_install_env() {
+                return Err(Error::Hook {
+                    hook: self.config.id.clone(),
+                    error: anyhow::anyhow!(
+                        "Hook specified `additional_dependencies: {}` but the language `{}` does not install an environment",
+                        additional_dependencies.join(", "),
+                        language,
+                    ),
+                });
+            }
+
+            if !language.supports_dependency() {
+                return Err(Error::Hook {
+                    hook: self.config.id.clone(),
+                    error: anyhow::anyhow!(
+                        "Hook specified `additional_dependencies: {}` but the language `{}` does not support installing dependencies for now",
+                        additional_dependencies.join(", "),
+                        language,
+                    ),
+                });
+            }
         }
 
-        if !language.supports_install_env() {
+        if !language.supports_language_version() {
             if let Some(language_version) = language_version
                 && language_version != "default"
             {
                 return Err(Error::Hook {
                     hook: self.config.id.clone(),
                     error: anyhow::anyhow!(
-                        "Hook specified `language_version` `{language_version}` but the language `{language}` does not install an environment"
-                    ),
-                });
-            }
-
-            if !additional_dependencies.is_empty() {
-                return Err(Error::Hook {
-                    hook: self.config.id.clone(),
-                    error: anyhow::anyhow!(
-                        "Hook specified `additional_dependencies` `{}` but the language `{}` does not install an environment",
-                        additional_dependencies.join(", "),
-                        language,
+                        "Hook specified `language_version: {language_version}` but the language `{language}` does not support toolchain installation for now",
                     ),
                 });
             }
@@ -368,10 +384,17 @@ impl Entry {
 
     /// Split the entry into a list of commands.
     pub(crate) fn split(&self) -> Result<Vec<String>, Error> {
-        shlex::split(&self.entry).ok_or_else(|| Error::Hook {
+        let splits = shlex::split(&self.entry).ok_or_else(|| Error::Hook {
             hook: self.hook.clone(),
             error: anyhow::anyhow!("Failed to parse entry `{}` as commands", &self.entry),
-        })
+        })?;
+        if splits.is_empty() {
+            return Err(Error::Hook {
+                hook: self.hook.clone(),
+                error: anyhow::anyhow!("Failed to parse entry: entry is empty"),
+            });
+        }
+        Ok(splits)
     }
 
     /// Get the original entry string.
@@ -536,7 +559,7 @@ impl InstalledHook {
     }
 }
 
-#[derive(Debug, Clone, Deserialize, Serialize)]
+#[derive(Debug, Deserialize, Serialize)]
 pub(crate) struct InstallInfo {
     pub(crate) language: Language,
     pub(crate) language_version: semver::Version,
@@ -544,42 +567,49 @@ pub(crate) struct InstallInfo {
     pub(crate) env_path: PathBuf,
     pub(crate) toolchain: PathBuf,
     extra: FxHashMap<String, String>,
+    #[serde(skip, default)]
+    temp_dir: Option<TempDir>,
 }
 
-impl Hash for InstallInfo {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        self.language.hash(state);
-        self.language_version.hash(state);
-        let mut deps = self.dependencies.iter().collect::<Vec<_>>();
-        deps.sort_unstable();
-        deps.hash(state);
+impl Clone for InstallInfo {
+    fn clone(&self) -> Self {
+        Self {
+            language: self.language,
+            language_version: self.language_version.clone(),
+            dependencies: self.dependencies.clone(),
+            env_path: self.env_path.clone(),
+            toolchain: self.toolchain.clone(),
+            extra: self.extra.clone(),
+            temp_dir: None,
+        }
     }
 }
 
-// TODO: detect collision
-fn random_directory() -> String {
-    rand::rng()
-        .sample_iter(&rand::distr::Alphanumeric)
-        .take(20)
-        .map(char::from)
-        .collect()
-}
-
 impl InstallInfo {
     pub(crate) fn new(
         language: Language,
         dependencies: FxHashSet<String>,
         hooks_dir: &Path,
-    ) -> Self {
-        let env = random_directory();
+    ) -> Result<Self, Error> {
+        let env_path = tempfile::Builder::new()
+            .prefix(&format!("{}-", language.as_str()))
+            .rand_bytes(20)
+            .tempdir_in(hooks_dir)?;
 
-        Self {
+        Ok(Self {
             language,
             dependencies,
-            env_path: hooks_dir.join(format!("{}-{env}", language.as_str())),
+            env_path: env_path.path().to_path_buf(),
             language_version: semver::Version::new(0, 0, 0),
             toolchain: PathBuf::new(),
             extra: FxHashMap::default(),
+            temp_dir: Some(env_path),
+        })
+    }
+
+    pub(crate) fn persist_env_path(&mut self) {
+        if let Some(temp_dir) = self.temp_dir.take() {
+            self.env_path = temp_dir.keep();
         }
     }
 
