@@ -4,7 +4,7 @@ use std::sync::Arc;
 
 use anyhow::Context;
 
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::cli::reporter::HookInstallReporter;
 use crate::hook::{Hook, InstallInfo, InstalledHook};
@@ -32,13 +32,13 @@ impl LanguageImpl for Golang {
         let go_dir = store.tools_path(crate::store::ToolBucket::Go);
         let installer = GoInstaller::new(go_dir);
 
-        let version = match &hook.language_request {
-            LanguageRequest::Any => &GoRequest::Any,
-            LanguageRequest::Golang(version) => version,
+        let (version, allows_download) = match &hook.language_request {
+            LanguageRequest::Any { system_only } => (&GoRequest::Any, !system_only),
+            LanguageRequest::Golang(version) => (version, true),
             _ => unreachable!(),
         };
         let go = installer
-            .install(store, version)
+            .install(store, version, allows_download)
             .await
             .context("Failed to install go")?;
 
@@ -46,12 +46,11 @@ impl LanguageImpl for Golang {
             hook.language,
             hook.dependencies().clone(),
             &store.hooks_dir(),
-        );
+        )?;
         info.with_toolchain(go.bin().to_path_buf())
             .with_language_version(go.version().deref().clone());
 
         // 2. Create environment
-        fs_err::tokio::create_dir_all(&info.env_path).await?;
         fs_err::tokio::create_dir_all(bin_dir(&info.env_path)).await?;
 
         // 3. Install dependencies
@@ -102,6 +101,8 @@ impl LanguageImpl for Golang {
             cmd.arg(dep).remove_git_env().check(true).output().await?;
         }
 
+        info.persist_env_path();
+
         reporter.on_install_complete(progress);
 
         Ok(InstalledHook::Installed {
@@ -138,7 +139,7 @@ impl LanguageImpl for Golang {
         let new_path = prepend_paths(&[&go_bin, go_root_bin]).context("Failed to join PATH")?;
 
         let entry = hook.entry.resolve(Some(&new_path))?;
-        let run = async move |batch: &[&Path]| {
+        let run = async |batch: &[&Path]| {
             let mut output = Cmd::new(&entry[0], "go hook")
                 .current_dir(hook.work_dir())
                 .args(&entry[1..])
@@ -157,7 +158,7 @@ impl LanguageImpl for Golang {
             anyhow::Ok((code, output.stdout))
         };
 
-        let results = run_by_batch(hook, filenames, run).await?;
+        let results = run_by_batch(hook, filenames, &entry, run).await?;
 
         let mut combined_status = 0;
         let mut combined_output = Vec::new();
