@@ -2,10 +2,11 @@ use std::env::consts::EXE_EXTENSION;
 use std::fmt::Display;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
+use std::sync::LazyLock;
 
 use anyhow::{Context, Result};
 use itertools::Itertools;
-use reqwest::Client;
+use prek_consts::env_vars::EnvVars;
 use target_lexicon::{Architecture, HOST, OperatingSystem};
 use tracing::{debug, trace, warn};
 
@@ -31,6 +32,15 @@ impl Display for GoResult {
     }
 }
 
+/// Override the Go binary name for testing.
+static GO_BINARY_NAME: LazyLock<String> = LazyLock::new(|| {
+    if let Ok(name) = EnvVars::var(EnvVars::PREK_INTERNAL__GO_BINARY_NAME) {
+        name
+    } else {
+        "go".to_string()
+    }
+});
+
 impl GoResult {
     fn from_executable(path: PathBuf, from_system: bool) -> Self {
         Self {
@@ -89,18 +99,19 @@ impl GoResult {
 
 pub(crate) struct GoInstaller {
     root: PathBuf,
-    client: Client,
 }
 
 impl GoInstaller {
     pub(crate) fn new(root: PathBuf) -> Self {
-        Self {
-            root,
-            client: Client::new(),
-        }
+        Self { root }
     }
 
-    pub(crate) async fn install(&self, store: &Store, request: &GoRequest) -> Result<GoResult> {
+    pub(crate) async fn install(
+        &self,
+        store: &Store,
+        request: &GoRequest,
+        allows_download: bool,
+    ) -> Result<GoResult> {
         fs_err::tokio::create_dir_all(&self.root).await?;
 
         let _lock = LockedFile::acquire(self.root.join(".lock"), "go").await?;
@@ -115,6 +126,10 @@ impl GoInstaller {
             return Ok(go);
         }
 
+        if !allows_download {
+            anyhow::bail!("No suitable system Go version found and downloads are disabled");
+        }
+
         let resolved_version = self
             .resolve_version(request)
             .await
@@ -212,7 +227,7 @@ impl GoInstaller {
         let url = format!("https://go.dev/dl/{filename}");
         let target = self.root.join(version.to_string());
 
-        download_and_extract(&self.client, &url, &filename, store, async |extracted| {
+        download_and_extract(&url, &filename, store, async |extracted| {
             if target.exists() {
                 debug!(target = %target.display(), "Removing existing go");
                 fs_err::tokio::remove_dir_all(&target).await?;
@@ -231,7 +246,7 @@ impl GoInstaller {
     }
 
     async fn find_system_go(&self, go_request: &GoRequest) -> Result<Option<GoResult>> {
-        let go_paths = match which::which_all("go") {
+        let go_paths = match which::which_all(&*GO_BINARY_NAME) {
             Ok(paths) => paths,
             Err(e) => {
                 debug!("No go executables found in PATH: {}", e);
