@@ -1,30 +1,33 @@
 use std::ffi::OsStr;
 use std::path::{Path, PathBuf};
+use std::str::FromStr;
 use std::sync::Arc;
 
 use anyhow::{Context, Result};
 use futures::TryStreamExt;
-use http::header::USER_AGENT;
+use prek_consts::env_vars::EnvVars;
 use tokio_util::compat::FuturesAsyncReadCompatExt;
-use tracing::{debug, trace};
+use tracing::{debug, error, instrument, trace};
 
 use crate::archive::ArchiveExtension;
 use crate::cli::reporter::HookInstallReporter;
 use crate::config::Language;
-use crate::fs::CWD;
-use crate::hook::{Hook, InstallInfo, InstalledHook};
+use crate::fs::{CWD, Simplified};
+use crate::hook::{Hook, InstallInfo, InstalledHook, Repo};
 use crate::identify::parse_shebang;
 use crate::store::Store;
 use crate::version::version;
-use crate::{archive, builtin};
+use crate::{archive, hooks, warn_user_once};
 
 mod docker;
 mod docker_image;
 mod fail;
 mod golang;
+mod lua;
 mod node;
 mod pygrep;
 mod python;
+mod ruby;
 mod script;
 mod system;
 pub mod version;
@@ -32,12 +35,14 @@ pub mod version;
 static GOLANG: golang::Golang = golang::Golang;
 static PYTHON: python::Python = python::Python;
 static NODE: node::Node = node::Node;
+static RUBY: ruby::Ruby = ruby::Ruby;
 static SYSTEM: system::System = system::System;
 static FAIL: fail::Fail = fail::Fail;
 static DOCKER: docker::Docker = docker::Docker;
 static DOCKER_IMAGE: docker_image::DockerImage = docker_image::DockerImage;
 static SCRIPT: script::Script = script::Script;
 static PYGREP: pygrep::Pygrep = pygrep::Pygrep;
+static LUA: lua::Lua = lua::Lua;
 static UNIMPLEMENTED: Unimplemented = Unimplemented;
 
 trait LanguageImpl {
@@ -47,7 +52,9 @@ trait LanguageImpl {
         store: &Store,
         reporter: &HookInstallReporter,
     ) -> Result<InstalledHook>;
+
     async fn check_health(&self, info: &InstallInfo) -> Result<()>;
+
     async fn run(
         &self,
         hook: &InstalledHook,
@@ -115,12 +122,14 @@ impl Language {
             Self::Golang
                 | Self::Python
                 | Self::Node
+                | Self::Ruby
                 | Self::System
                 | Self::Fail
                 | Self::Docker
                 | Self::DockerImage
                 | Self::Script
                 | Self::Pygrep
+                | Self::Lua
         )
     }
 
@@ -137,7 +146,7 @@ impl Language {
     pub fn supports_language_version(self) -> bool {
         matches!(
             self,
-            Self::Python | Self::Node | Self::Ruby | Self::Rust | Self::Golang
+            Self::Python | Self::Node | Self::Golang | Self::Ruby | Self::Rust
         )
     }
 
@@ -169,12 +178,14 @@ impl Language {
             Self::Golang => GOLANG.install(hook, store, reporter).await,
             Self::Python => PYTHON.install(hook, store, reporter).await,
             Self::Node => NODE.install(hook, store, reporter).await,
+            Self::Ruby => RUBY.install(hook, store, reporter).await,
             Self::System => SYSTEM.install(hook, store, reporter).await,
             Self::Fail => FAIL.install(hook, store, reporter).await,
             Self::Docker => DOCKER.install(hook, store, reporter).await,
             Self::DockerImage => DOCKER_IMAGE.install(hook, store, reporter).await,
             Self::Script => SCRIPT.install(hook, store, reporter).await,
             Self::Pygrep => PYGREP.install(hook, store, reporter).await,
+            Self::Lua => LUA.install(hook, store, reporter).await,
             _ => UNIMPLEMENTED.install(hook, store, reporter).await,
         }
     }
@@ -184,91 +195,106 @@ impl Language {
             Self::Golang => GOLANG.check_health(info).await,
             Self::Python => PYTHON.check_health(info).await,
             Self::Node => NODE.check_health(info).await,
+            Self::Ruby => RUBY.check_health(info).await,
             Self::System => SYSTEM.check_health(info).await,
             Self::Fail => FAIL.check_health(info).await,
             Self::Docker => DOCKER.check_health(info).await,
             Self::DockerImage => DOCKER_IMAGE.check_health(info).await,
             Self::Script => SCRIPT.check_health(info).await,
             Self::Pygrep => PYGREP.check_health(info).await,
+            Self::Lua => LUA.check_health(info).await,
             _ => UNIMPLEMENTED.check_health(info).await,
         }
     }
 
+    #[instrument(level = "trace", skip_all, fields(hook_id = %hook.id, language = %hook.language))]
     pub async fn run(
         &self,
         hook: &InstalledHook,
         filenames: &[&Path],
         store: &Store,
     ) -> Result<(i32, Vec<u8>)> {
-        // fast path for hooks implemented in Rust
-        if builtin::check_fast_path(hook) {
-            return builtin::run_fast_path(store, hook, filenames).await;
+        match hook.repo() {
+            Repo::Meta { .. } => {
+                return hooks::MetaHooks::from_str(&hook.id)
+                    .unwrap()
+                    .run(store, hook, filenames)
+                    .await;
+            }
+            Repo::Builtin { .. } => {
+                return hooks::BuiltinHooks::from_str(&hook.id)
+                    .unwrap()
+                    .run(store, hook, filenames)
+                    .await;
+            }
+            Repo::Remote { .. } => {
+                // Fast path for hooks implemented in Rust
+                if hooks::check_fast_path(hook) {
+                    return hooks::run_fast_path(store, hook, filenames).await;
+                }
+            }
+            Repo::Local { .. } => {}
         }
 
         match self {
             Self::Golang => GOLANG.run(hook, filenames, store).await,
             Self::Python => PYTHON.run(hook, filenames, store).await,
             Self::Node => NODE.run(hook, filenames, store).await,
+            Self::Ruby => RUBY.run(hook, filenames, store).await,
             Self::System => SYSTEM.run(hook, filenames, store).await,
             Self::Fail => FAIL.run(hook, filenames, store).await,
             Self::Docker => DOCKER.run(hook, filenames, store).await,
             Self::DockerImage => DOCKER_IMAGE.run(hook, filenames, store).await,
             Self::Script => SCRIPT.run(hook, filenames, store).await,
             Self::Pygrep => PYGREP.run(hook, filenames, store).await,
+            Self::Lua => LUA.run(hook, filenames, store).await,
             _ => UNIMPLEMENTED.run(hook, filenames, store).await,
         }
     }
 }
 
 /// Try to extract metadata from the given hook entry if possible.
-///
-/// Currently, only PEP 723 inline metadata for `python` hooks is supported.
-/// First part of `entry` must be a file path to the Python script.
-/// Effectively, we are implementing a new `python-script` language which works like `script`.
-/// But we don't want to introduce a new language just for this for now.
 pub(crate) async fn extract_metadata_from_entry(hook: &mut Hook) -> Result<()> {
-    // Only support `python` hooks for now.
-    if hook.language == Language::Python {
-        return python::extract_pep723_metadata(hook).await;
+    match hook.language {
+        Language::Python => python::extract_pep723_metadata(hook).await,
+        Language::Golang => golang::extract_go_mod_metadata(hook).await,
+        _ => Ok(()),
     }
-
-    Ok(())
 }
 
-pub(crate) fn resolve_command(mut cmds: Vec<String>, env_path: Option<&OsStr>) -> Vec<String> {
-    let cmd = &cmds[0];
-    let exe_path = match which::which_in(cmd, env_path, &*CWD) {
+/// Resolve the actual process invocation, honoring shebangs and PATH lookups.
+pub(crate) fn resolve_command(mut cmds: Vec<String>, paths: Option<&OsStr>) -> Vec<String> {
+    let candidate = &cmds[0];
+    let resolved_binary = match which::which_in(candidate, paths, &*CWD) {
         Ok(p) => p,
-        Err(_) => PathBuf::from(cmd),
+        Err(_) => PathBuf::from(candidate),
     };
-    trace!("Resolved command: {}", exe_path.display());
+    trace!("Resolved command: {}", resolved_binary.display());
 
-    if let Ok(mut interpreter) = parse_shebang(&exe_path) {
-        trace!("Found shebang: {:?}", interpreter);
+    if let Ok(mut shebang_argv) = parse_shebang(&resolved_binary) {
+        trace!("Found shebang: {:?}", shebang_argv);
         // Resolve the interpreter path, convert "python3" to "python3.exe" on Windows
-        if let Ok(p) = which::which_in(&interpreter[0], env_path, &*CWD) {
-            interpreter[0] = p.to_string_lossy().to_string();
-            trace!("Resolved interpreter: {}", &interpreter[0]);
+        if let Ok(p) = which::which_in(&shebang_argv[0], paths, &*CWD) {
+            shebang_argv[0] = p.to_string_lossy().to_string();
+            trace!("Resolved interpreter: {}", &shebang_argv[0]);
         }
-        interpreter.push(exe_path.to_string_lossy().to_string());
-        interpreter.extend_from_slice(&cmds[1..]);
-        interpreter
+        shebang_argv.push(resolved_binary.to_string_lossy().to_string());
+        shebang_argv.extend_from_slice(&cmds[1..]);
+        shebang_argv
     } else {
-        cmds[0] = exe_path.to_string_lossy().to_string();
+        cmds[0] = resolved_binary.to_string_lossy().to_string();
         cmds
     }
 }
 
 async fn download_and_extract(
-    client: &reqwest::Client,
     url: &str,
     filename: &str,
     store: &Store,
     callback: impl AsyncFn(&Path) -> Result<()>,
 ) -> Result<()> {
-    let response = client
+    let response = REQWEST_CLIENT
         .get(url)
-        .header(USER_AGENT, format!("prek/{}", version()))
         .send()
         .await
         .with_context(|| format!("Failed to download file from {url}"))?;
@@ -287,8 +313,6 @@ async fn download_and_extract(
         .compat();
 
     let scratch_dir = store.scratch_path();
-    fs_err::tokio::create_dir_all(&scratch_dir).await?;
-
     let temp_dir = tempfile::tempdir_in(&scratch_dir)?;
     debug!(url = %url, temp_dir = ?temp_dir.path(), "Downloading");
 
@@ -307,3 +331,56 @@ async fn download_and_extract(
 
     Ok(())
 }
+
+pub(crate) static REQWEST_CLIENT: std::sync::LazyLock<reqwest::Client> =
+    std::sync::LazyLock::new(|| {
+        let native_tls = use_native_tls();
+        create_reqwest_client(native_tls)
+    });
+
+fn create_reqwest_client(native_tls: bool) -> reqwest::Client {
+    let builder = reqwest::ClientBuilder::new()
+        .user_agent(format!("prek/{}", crate::version::version()))
+        .tls_built_in_root_certs(false);
+    let builder = if native_tls {
+        debug!("Using native TLS for reqwest client");
+        builder.tls_built_in_native_certs(true)
+    } else {
+        builder.tls_built_in_webpki_certs(true)
+    };
+    builder.build().unwrap_or_else(|e| {
+        error!(
+            "Unable to create reqwest client, falling back to default {:?}",
+            e
+        );
+        reqwest::Client::new()
+    })
+}
+
+fn use_native_tls() -> bool {
+    if let Some(val) = EnvVars::var_as_bool(EnvVars::PREK_NATIVE_TLS) {
+        return val;
+    }
+
+    // SSL_CERT_FILE is only respected when using native TLS
+    EnvVars::var_os(EnvVars::SSL_CERT_FILE).is_some_and(|path| {
+        let path_exists = Path::new(&path).exists();
+        if !path_exists {
+            warn_user_once!(
+                "Ignoring invalid `SSL_CERT_FILE`. File does not exist: {}.",
+                path.simplified_display().cyan()
+            );
+        }
+        path_exists
+    })
+}
+
+#[cfg(test)]
+mod tests {
+    #[tokio::test]
+    async fn test_native_tls() {
+        let client = super::create_reqwest_client(true);
+        let resp = client.get("https://github.com").send().await;
+        assert!(resp.is_ok(), "Failed to send request with native TLS");
+    }
+}
