@@ -4,7 +4,7 @@ use std::path::{Path, PathBuf};
 use std::sync::Arc;
 
 use anyhow::{Context, Result};
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 use rustc_hash::FxHashSet;
 use tracing::debug;
 
@@ -43,13 +43,13 @@ impl LanguageImpl for Node {
         let node_dir = store.tools_path(ToolBucket::Node);
         let installer = NodeInstaller::new(node_dir);
 
-        let node_request = match &hook.language_request {
-            LanguageRequest::Any => &NodeRequest::Any,
-            LanguageRequest::Node(node_request) => node_request,
+        let (node_request, allows_download) = match &hook.language_request {
+            LanguageRequest::Any { system_only } => (&NodeRequest::Any, !system_only),
+            LanguageRequest::Node(node_request) => (node_request, true),
             _ => unreachable!(),
         };
         let node = installer
-            .install(store, node_request)
+            .install(store, node_request, allows_download)
             .await
             .context("Failed to install node")?;
 
@@ -57,7 +57,7 @@ impl LanguageImpl for Node {
             hook.language,
             hook.dependencies().clone(),
             &store.hooks_dir(),
-        );
+        )?;
 
         let lts = serde_json::to_string(&node.version().lts).context("Failed to serialize LTS")?;
         info.with_toolchain(node.node().to_path_buf());
@@ -121,6 +121,8 @@ impl LanguageImpl for Node {
                 .await?;
         }
 
+        info.persist_env_path();
+
         reporter.on_install_complete(progress);
 
         Ok(InstalledHook::Installed {
@@ -156,7 +158,7 @@ impl LanguageImpl for Node {
         let new_path = prepend_paths(&[&bin_dir(env_dir)]).context("Failed to join PATH")?;
 
         let entry = hook.entry.resolve(Some(&new_path))?;
-        let run = async move |batch: &[&Path]| {
+        let run = async |batch: &[&Path]| {
             let mut output = Cmd::new(&entry[0], "node hook")
                 .current_dir(hook.work_dir())
                 .args(&entry[1..])
@@ -175,7 +177,7 @@ impl LanguageImpl for Node {
             anyhow::Ok((code, output.stdout))
         };
 
-        let results = run_by_batch(hook, filenames, run).await?;
+        let results = run_by_batch(hook, filenames, &entry, run).await?;
 
         // Collect results
         let mut combined_status = 0;
