@@ -5,7 +5,7 @@ use std::sync::Arc;
 use anyhow::{Context, Result};
 use tracing::{debug, trace};
 
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::cli::reporter::HookInstallReporter;
 use crate::hook::InstalledHook;
@@ -63,23 +63,6 @@ pub(crate) async fn query_python_info(python: &Path) -> Result<PythonInfo> {
     })
 }
 
-fn to_uv_python_request(request: &LanguageRequest) -> Option<String> {
-    match request {
-        LanguageRequest::Any => None,
-        LanguageRequest::Python(request) => match request {
-            PythonRequest::Any => None,
-            PythonRequest::Major(major) => Some(format!("{major}")),
-            PythonRequest::MajorMinor(major, minor) => Some(format!("{major}.{minor}")),
-            PythonRequest::MajorMinorPatch(major, minor, patch) => {
-                Some(format!("{major}.{minor}.{patch}"))
-            }
-            PythonRequest::Range(_, raw) => Some(raw.clone()),
-            PythonRequest::Path(path) => Some(path.to_string_lossy().to_string()),
-        },
-        _ => unreachable!(),
-    }
-}
-
 impl LanguageImpl for Python {
     async fn install(
         &self,
@@ -98,14 +81,12 @@ impl LanguageImpl for Python {
             hook.language,
             hook.dependencies().clone(),
             &store.hooks_dir(),
-        );
+        )?;
 
         debug!(%hook, target = %info.env_path.display(), "Installing environment");
 
-        let python_request = to_uv_python_request(&hook.language_request);
-
         // Create venv (auto download Python if needed)
-        Self::create_venv_with_retry(&uv, store, &info, python_request.as_ref())
+        Self::create_venv(&uv, store, &info, &hook.language_request)
             .await
             .context("Failed to create Python virtual environment")?;
 
@@ -116,12 +97,17 @@ impl LanguageImpl for Python {
                 repo_path.display()
             );
             uv.cmd("uv pip install", store)
+                .arg("--directory")
+                .arg(repo_path)
                 .arg("pip")
                 .arg("install")
                 .arg(".")
                 .args(&hook.additional_dependencies)
-                .current_dir(repo_path)
-                .env("VIRTUAL_ENV", &info.env_path)
+                .env(EnvVars::VIRTUAL_ENV, &info.env_path)
+                // Make sure uv uses the venv's python
+                .env_remove(EnvVars::UV_PYTHON)
+                .env_remove(EnvVars::UV_MANAGED_PYTHON)
+                .env_remove(EnvVars::UV_NO_MANAGED_PYTHON)
                 .check(true)
                 .output()
                 .await?;
@@ -131,7 +117,11 @@ impl LanguageImpl for Python {
                 .arg("pip")
                 .arg("install")
                 .args(&hook.additional_dependencies)
-                .env("VIRTUAL_ENV", &info.env_path)
+                .env(EnvVars::VIRTUAL_ENV, &info.env_path)
+                // Make sure uv uses the venv's python
+                .env_remove(EnvVars::UV_PYTHON)
+                .env_remove(EnvVars::UV_MANAGED_PYTHON)
+                .env_remove(EnvVars::UV_NO_MANAGED_PYTHON)
                 .check(true)
                 .output()
                 .await?;
@@ -147,6 +137,8 @@ impl LanguageImpl for Python {
         info.with_language_version(python_info.version)
             .with_toolchain(python_info.python_exec);
 
+        info.persist_env_path();
+
         reporter.on_install_complete(progress);
 
         Ok(InstalledHook::Installed {
@@ -190,13 +182,13 @@ impl LanguageImpl for Python {
         let new_path = prepend_paths(&[&bin_dir(env_dir)]).context("Failed to join PATH")?;
         let entry = hook.entry.resolve(Some(&new_path))?;
 
-        let run = async move |batch: &[&Path]| {
+        let run = async |batch: &[&Path]| {
             let mut output = Cmd::new(&entry[0], "python hook")
                 .current_dir(hook.work_dir())
                 .args(&entry[1..])
-                .env("VIRTUAL_ENV", env_dir)
-                .env("PATH", &new_path)
-                .env_remove("PYTHONHOME")
+                .env(EnvVars::VIRTUAL_ENV, env_dir)
+                .env(EnvVars::PATH, &new_path)
+                .env_remove(EnvVars::PYTHONHOME)
                 .args(&hook.args)
                 .args(batch)
                 .check(false)
@@ -208,7 +200,7 @@ impl LanguageImpl for Python {
             anyhow::Ok((code, output.stdout))
         };
 
-        let results = run_by_batch(hook, filenames, run).await?;
+        let results = run_by_batch(hook, filenames, &entry, run).await?;
 
         // Collect results
         let mut combined_status = 0;
@@ -223,12 +215,29 @@ impl LanguageImpl for Python {
     }
 }
 
+fn to_uv_python_request(request: &LanguageRequest) -> Option<String> {
+    match request {
+        LanguageRequest::Any { .. } => None,
+        LanguageRequest::Python(request) => match request {
+            PythonRequest::Any => None,
+            PythonRequest::Major(major) => Some(format!("{major}")),
+            PythonRequest::MajorMinor(major, minor) => Some(format!("{major}.{minor}")),
+            PythonRequest::MajorMinorPatch(major, minor, patch) => {
+                Some(format!("{major}.{minor}.{patch}"))
+            }
+            PythonRequest::Range(_, raw) => Some(raw.clone()),
+            PythonRequest::Path(path) => Some(path.to_string_lossy().to_string()),
+        },
+        _ => unreachable!(),
+    }
+}
+
 impl Python {
-    async fn create_venv_with_retry(
+    async fn create_venv(
         uv: &Uv,
         store: &Store,
         info: &InstallInfo,
-        python_request: Option<&String>,
+        python_request: &LanguageRequest,
     ) -> Result<()> {
         // Try creating venv without downloads first
         match Self::create_venv_command(uv, store, info, python_request, false, false)
@@ -246,6 +255,12 @@ impl Python {
             Err(e @ process::Error::Status { .. }) => {
                 // Check if we can retry with downloads
                 if Self::can_retry_with_downloads(&e) {
+                    if !python_request.allows_download() {
+                        anyhow::bail!(
+                            "No suitable system Python version found and downloads are disabled"
+                        );
+                    }
+
                     debug!(
                         "Retrying venv creation with managed Python downloads: `{}`",
                         info.env_path.display()
@@ -270,7 +285,7 @@ impl Python {
         uv: &Uv,
         store: &Store,
         info: &InstallInfo,
-        python_request: Option<&String>,
+        python_request: &LanguageRequest,
         set_install_dir: bool,
         allow_downloads: bool,
     ) -> Cmd {
@@ -297,7 +312,7 @@ impl Python {
             cmd.arg("--no-python-downloads");
         }
 
-        if let Some(python) = python_request {
+        if let Some(python) = to_uv_python_request(python_request) {
             cmd.arg("--python").arg(python);
         }
 
