@@ -45,12 +45,13 @@ impl LanguageImpl for Script {
         split[0] = cmd.to_string_lossy().to_string();
         let entry = resolve_command(split, None);
 
-        let run = async move |batch: &[&Path]| {
+        let run = async |batch: &[&Path]| {
             let mut output = Cmd::new(&entry[0], "run script command")
                 .current_dir(hook.work_dir())
                 .args(&entry[1..])
                 .args(&hook.args)
                 .args(batch)
+                .check(false)
                 .pty_output()
                 .await?;
 
@@ -59,7 +60,7 @@ impl LanguageImpl for Script {
             anyhow::Ok((code, output.stdout))
         };
 
-        let results = run_by_batch(hook, filenames, run).await?;
+        let results = run_by_batch(hook, filenames, &entry, run).await?;
 
         // Collect results
         let mut combined_status = 0;
