@@ -35,7 +35,7 @@ impl LanguageImpl for System {
     ) -> Result<(i32, Vec<u8>)> {
         let entry = hook.entry.resolve(None)?;
 
-        let run = async move |batch: &[&Path]| {
+        let run = async |batch: &[&Path]| {
             let mut output = Cmd::new(&entry[0], "run system command")
                 .current_dir(hook.work_dir())
                 .args(&entry[1..])
@@ -50,7 +50,7 @@ impl LanguageImpl for System {
             anyhow::Ok((code, output.stdout))
         };
 
-        let results = run_by_batch(hook, filenames, run).await?;
+        let results = run_by_batch(hook, filenames, &entry, run).await?;
 
         // Collect results
         let mut combined_status = 0;
