@@ -5,6 +5,7 @@ use crate::hook::InstallInfo;
 use crate::languages::golang::GoRequest;
 use crate::languages::node::NodeRequest;
 use crate::languages::python::PythonRequest;
+use crate::languages::ruby::RubyRequest;
 
 #[derive(thiserror::Error, Debug)]
 pub(crate) enum Error {
@@ -14,10 +15,11 @@ pub(crate) enum Error {
 
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub(crate) enum LanguageRequest {
-    Any,
+    Any { system_only: bool },
     Python(PythonRequest),
     Node(NodeRequest),
     Golang(GoRequest),
+    Ruby(RubyRequest),
     // TODO: all other languages default to semver for now.
     Semver(SemverRequest),
 }
@@ -25,14 +27,27 @@ pub(crate) enum LanguageRequest {
 impl LanguageRequest {
     pub(crate) fn is_any(&self) -> bool {
         match self {
-            LanguageRequest::Any => true,
+            LanguageRequest::Any { .. } => true,
             LanguageRequest::Python(req) => req.is_any(),
             LanguageRequest::Node(req) => req.is_any(),
             LanguageRequest::Golang(req) => req.is_any(),
+            LanguageRequest::Ruby(req) => req.is_any(),
             LanguageRequest::Semver(_) => false,
         }
     }
 
+    /// Returns true if this request allows downloading a version.
+    ///
+    /// Currently, only `system` disallows downloading. In the future,
+    /// we may add more specific version requests that also disallow downloading.
+    /// For example `language_version: 3.12; system_only`.
+    pub(crate) fn allows_download(&self) -> bool {
+        match self {
+            LanguageRequest::Any { system_only } => !system_only,
+            _ => true,
+        }
+    }
+
     pub(crate) fn parse(lang: Language, request: &str) -> Result<Self, Error> {
         // `pre-commit` support these values in `language_version`:
         // - `default`: substituted by language `get_default_version` function
@@ -44,25 +59,29 @@ impl LanguageRequest {
         // - Node.js version passed down to `nodeenv`
         // - Rust version passed down to `rustup`
 
-        // TODO: support `system`? Does anyone use it?
         if request == "default" || request.is_empty() {
-            return Ok(LanguageRequest::Any);
+            return Ok(LanguageRequest::Any { system_only: false });
+        }
+        if request == "system" {
+            return Ok(LanguageRequest::Any { system_only: true });
         }
 
         Ok(match lang {
             Language::Python => Self::Python(request.parse()?),
             Language::Node => Self::Node(request.parse()?),
             Language::Golang => Self::Golang(request.parse()?),
+            Language::Ruby => Self::Ruby(request.parse()?),
             _ => Self::Semver(request.parse()?),
         })
     }
 
     pub(crate) fn satisfied_by(&self, install_info: &InstallInfo) -> bool {
         match self {
-            LanguageRequest::Any => true,
+            LanguageRequest::Any { .. } => true,
             LanguageRequest::Python(req) => req.satisfied_by(install_info),
             LanguageRequest::Node(req) => req.satisfied_by(install_info),
             LanguageRequest::Golang(req) => req.satisfied_by(install_info),
+            LanguageRequest::Ruby(req) => req.satisfied_by(install_info),
             LanguageRequest::Semver(req) => req.satisfied_by(install_info),
         }
     }
