@@ -4,7 +4,7 @@ use std::process::ExitCode;
 use std::str::FromStr;
 use std::sync::Mutex;
 
-use anstream::{ColorChoice, StripStream, eprintln};
+use anstream::{StripStream, eprintln};
 use anyhow::{Context, Result};
 use clap::{CommandFactory, Parser};
 use clap_complete::CompleteEnv;
@@ -22,17 +22,17 @@ use crate::cli::{CacheCommand, CacheNamespace, Cli, Command, ExitStatus};
 #[cfg(feature = "self-update")]
 use crate::cli::{SelfCommand, SelfNamespace, SelfUpdateArgs};
 use crate::printer::Printer;
-use crate::run::USE_COLOR;
+use crate::run::{USE_COLOR, write_color_choice};
 use crate::store::Store;
 
 mod archive;
-mod builtin;
 mod cleanup;
 mod cli;
 mod config;
 mod fs;
 mod git;
 mod hook;
+mod hooks;
 mod identify;
 mod languages;
 mod printer;
@@ -44,6 +44,7 @@ mod store;
 mod version;
 mod warnings;
 mod workspace;
+mod yaml;
 
 #[derive(Debug, Default, Clone, Copy, PartialEq, Eq)]
 pub(crate) enum Level {
@@ -96,7 +97,6 @@ fn setup_logging(level: Level, log_file: LogFile, store: &Store) -> Result<()> {
         .context("Invalid RUST_LOG directive")?;
     let stderr_format = tracing_subscriber::fmt::format()
         .with_target(false)
-        .without_time()
         .with_ansi(*USE_COLOR);
     let stderr_layer = tracing_subscriber::fmt::layer()
         .with_span_events(FmtSpan::CLOSE)
@@ -138,7 +138,7 @@ fn setup_logging(level: Level, log_file: LogFile, store: &Store) -> Result<()> {
 }
 
 async fn run(mut cli: Cli) -> Result<ExitStatus> {
-    ColorChoice::write_global(cli.globals.color.into());
+    write_color_choice(cli.globals.color);
 
     let store = Store::from_settings()?;
     let log_file = LogFile::from_args(cli.globals.log_file.clone(), cli.globals.no_log_file);
@@ -220,7 +220,6 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
             .await
         }
         Command::InstallHooks(args) => {
-            // TODO: add selectors?
             cli::install_hooks(
                 &store,
                 cli.globals.config,
@@ -252,6 +251,7 @@ async fn run(mut cli: Cli) -> Result<ExitStatus> {
                 args.directory,
                 args.last_commit,
                 args.show_diff_on_failure,
+                args.fail_fast,
                 args.dry_run,
                 cli.globals.refresh,
                 args.extra,
@@ -414,16 +414,8 @@ fn main() -> ExitCode {
         Err(err) => err.exit(),
     };
 
-    // Initialize the profiler guard if the feature is enabled.
-    let mut _profiler_guard = None;
     #[cfg(all(unix, feature = "profiler"))]
-    {
-        _profiler_guard = profiler::start_profiling();
-    }
-    #[cfg(not(all(unix, feature = "profiler")))]
-    {
-        _profiler_guard = Some(());
-    }
+    let _profiler_guard = profiler::start_profiling();
 
     let runtime = tokio::runtime::Builder::new_current_thread()
         .enable_all()
@@ -434,9 +426,7 @@ fn main() -> ExitCode {
 
     // Report the profiler if the feature is enabled
     #[cfg(all(unix, feature = "profiler"))]
-    {
-        profiler::finish_profiling(_profiler_guard);
-    }
+    profiler::finish_profiling(_profiler_guard);
 
     match result {
         Ok(code) => code.into(),
