@@ -4,20 +4,58 @@ use std::path::Path;
 use std::sync::LazyLock;
 
 use anstream::ColorChoice;
+use anstream::stream::IsTerminal;
 use futures::StreamExt;
+use prek_consts::env_vars::EnvVars;
 use tracing::trace;
 
-use constants::env_vars::EnvVars;
-
+use crate::cli;
 use crate::hook::Hook;
 
-pub(crate) static USE_COLOR: LazyLock<bool> = LazyLock::new(|| {
-    match anstream::Stderr::choice(&std::io::stderr()) {
-        ColorChoice::Always | ColorChoice::AlwaysAnsi => true,
-        ColorChoice::Never => false,
-        // We just asked anstream for a choice, that can't be auto
-        ColorChoice::Auto => unreachable!(),
+fn detect_color_choice(color: cli::ColorChoice) -> bool {
+    match color {
+        cli::ColorChoice::Always => true,
+        cli::ColorChoice::Never => false,
+        cli::ColorChoice::Auto => {
+            let mut term_supports_color = anstyle_query::term_supports_color();
+            if !term_supports_color {
+                if let Some(enabled) = anstyle_query::windows::enable_ansi_colors() {
+                    term_supports_color = enabled;
+                }
+            }
+
+            // Inline the logic from `anstream::choice()`.
+            let clicolor = anstyle_query::clicolor();
+            let clicolor_enabled = clicolor.unwrap_or(false);
+            let clicolor_disabled = !clicolor.unwrap_or(true);
+            if anstyle_query::no_color() {
+                false
+            } else if anstyle_query::clicolor_force() {
+                true
+            } else if clicolor_disabled {
+                false
+            } else {
+                std::io::stderr().is_terminal()
+                    && (term_supports_color || clicolor_enabled || anstyle_query::is_ci())
+            }
+        }
     }
+}
+
+pub(crate) fn write_color_choice(choice: cli::ColorChoice) {
+    let enabled = detect_color_choice(choice);
+
+    ColorChoice::write_global(if enabled {
+        ColorChoice::Always
+    } else {
+        ColorChoice::Never
+    });
+}
+
+pub(crate) static USE_COLOR: LazyLock<bool> = LazyLock::new(|| match ColorChoice::global() {
+    ColorChoice::Always | ColorChoice::AlwaysAnsi => true,
+    ColorChoice::Never => false,
+    ColorChoice::Auto => unreachable!(),
 });
 
 pub(crate) static CONCURRENCY: LazyLock<usize> = LazyLock::new(|| {
@@ -70,11 +108,29 @@ fn platform_max_cli_length() -> usize {
 }
 
 impl<'a> Partitions<'a> {
-    fn new(hook: &'a Hook, filenames: &'a [&'a Path], concurrency: usize) -> Self {
+    fn new(
+        hook: &'a Hook,
+        entry: &'a [String],
+        filenames: &'a [&'a Path],
+        concurrency: usize,
+    ) -> Self {
         let max_per_batch = max(4, filenames.len().div_ceil(concurrency));
-        let max_cli_length = platform_max_cli_length();
+        let mut max_cli_length = platform_max_cli_length();
 
-        let command_length = hook.entry.raw().len()
+        let entry_lower = &entry[0].to_ascii_lowercase();
+        if cfg!(windows)
+            && [".bat", ".cmd"]
+                .iter()
+                .any(|ext| entry_lower.ends_with(ext))
+        {
+            // Reduce max length for batch files on Windows due to cmd.exe limitations.
+            // 1024 is additionally subtracted to give headroom for further
+            // expansion inside the batch file.
+            max_cli_length = 8192 - 1024;
+        }
+
+        let command_length = entry.iter().map(String::len).sum::<usize>()
+            + entry.len()
             + hook.args.iter().map(String::len).sum::<usize>()
             + hook.args.len();
 
@@ -107,7 +163,7 @@ impl<'a> Iterator for Partitions<'a> {
 
         while self.current_index < self.filenames.len() {
             let filename = self.filenames[self.current_index];
-            let length = filename.to_string_lossy().len() + 1;
+            let length = filename.as_os_str().len() + 1;
 
             if current_length + length > self.max_cli_length
                 || self.current_index - start_index >= self.max_per_batch
@@ -130,6 +186,7 @@ impl<'a> Iterator for Partitions<'a> {
 pub(crate) async fn run_by_batch<T, F>(
     hook: &Hook,
     filenames: &[&Path],
+    entry: &[String],
     run: F,
 ) -> anyhow::Result<Vec<T>>
 where
@@ -139,7 +196,7 @@ where
     let concurrency = target_concurrency(hook.require_serial);
 
     // Split files into batches
-    let partitions = Partitions::new(hook, filenames, concurrency);
+    let partitions = Partitions::new(hook, entry, filenames, concurrency);
     trace!(
         total_files = filenames.len(),
         concurrency = concurrency,
