@@ -6,15 +6,15 @@ use std::sync::{Arc, Mutex};
 use std::time::SystemTime;
 
 use anyhow::Result;
-use constants::{ALT_CONFIG_FILE, CONFIG_FILE};
 use futures::StreamExt;
 use ignore::WalkState;
 use itertools::zip_eq;
 use owo_colors::OwoColorize;
+use prek_consts::{ALT_CONFIG_FILE, CONFIG_FILE};
 use rustc_hash::{FxHashMap, FxHashSet};
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
-use tracing::{debug, error, instrument};
+use tracing::{debug, error, instrument, trace};
 
 use crate::cli::run::Selectors;
 use crate::config::{self, Config, ManifestHook, read_config};
@@ -37,7 +37,8 @@ pub(crate) enum Error {
     Git(#[from] anyhow::Error),
 
     #[error(
-        "No `.pre-commit-config.yaml` found in the current directory or parent directories in the repository"
+        "No `.pre-commit-config.yaml` found in the current directory or parent directories.\n\n{} If you just added one, rerun your command with the `--refresh` flag to rescan the workspace.",
+        "hint:".yellow().bold(),
     )]
     MissingPreCommitConfig,
 
@@ -91,7 +92,7 @@ impl PartialEq for Project {
 impl Eq for Project {}
 
 impl Hash for Project {
-    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
+    fn hash<H: Hasher>(&self, state: &mut H) {
         self.config_path.hash(state);
     }
 }
@@ -250,7 +251,7 @@ impl Project {
                 .map(async |repo_config| {
                     let path = store.clone_repo(repo_config, reporter).await.map_err(|e| {
                         Error::Store {
-                            repo: repo_config.repo.to_string(),
+                            repo: repo_config.repo.clone(),
                             error: Box::new(e),
                         }
                     })?;
@@ -292,6 +293,10 @@ impl Project {
                     let repo = Repo::meta(repo.hooks.clone());
                     repos.push(Arc::new(repo));
                 }
+                config::Repo::Builtin(repo) => {
+                    let repo = Repo::builtin(repo.hooks.clone());
+                    repos.push(Arc::new(repo));
+                }
             }
         }
 
@@ -349,6 +354,18 @@ impl Project {
                         hooks.push(hook);
                     }
                 }
+                config::Repo::Builtin(repo_config) => {
+                    for hook_config in &repo_config.hooks {
+                        let repo = Arc::clone(repo);
+                        let hook_config = ManifestHook::from(hook_config.clone());
+                        let mut builder =
+                            HookBuilder::new(self.clone(), repo, hook_config, hooks.len());
+                        builder.combine(&self.config);
+
+                        let hook = builder.build().await?;
+                        hooks.push(hook);
+                    }
+                }
             }
         }
 
@@ -616,6 +633,10 @@ impl Workspace {
         if let Some(selectors) = selectors {
             projects.retain(|p| selectors.matches_path(p.relative_path()));
         }
+        if projects.is_empty() {
+            return Err(MissingPreCommitConfig);
+        }
+
         let mut workspace = Self { root, projects };
         workspace.sort_and_index_projects();
 
@@ -629,6 +650,9 @@ impl Workspace {
     ) -> Result<Vec<Arc<Project>>, Error> {
         let projects = Mutex::new(Ok(Vec::new()));
 
+        let git_root = GIT_ROOT.as_ref().map_err(|e| Error::Git(e.into()))?;
+        let submodules = git::list_submodules(git_root).unwrap_or_default();
+
         ignore::WalkBuilder::new(root)
             .follow_links(false)
             .add_custom_ignore_filename(".prekignore")
@@ -644,6 +668,17 @@ impl Workspace {
                     if !file_type.is_dir() {
                         return WalkState::Continue;
                     }
+                    // Skip git submodules
+                    if submodules
+                        .iter()
+                        .any(|submodule| entry.path().starts_with(submodule))
+                    {
+                        trace!(
+                            path = %entry.path().user_display(),
+                            "Skipping git submodule"
+                        );
+                        return WalkState::Skip;
+                    }
 
                     match Project::from_directory(entry.path()) {
                         Ok(mut project) => {
@@ -685,7 +720,9 @@ impl Workspace {
             });
 
         let projects = projects.into_inner().unwrap()?;
-        debug_assert!(!projects.is_empty(), "At least one project should be found");
+        if projects.is_empty() {
+            return Err(MissingPreCommitConfig);
+        }
 
         Ok(projects)
     }
@@ -746,7 +783,7 @@ impl Workspace {
                         .clone_repo(&repo_config, reporter)
                         .await
                         .map_err(|e| Error::Store {
-                            repo: repo_config.repo.to_string(),
+                            repo: repo_config.repo.clone(),
                             error: Box::new(e),
                         })?;
 
@@ -790,6 +827,10 @@ impl Workspace {
                         let repo = Repo::meta(repo.hooks.clone());
                         repos.push(Arc::new(repo));
                     }
+                    config::Repo::Builtin(repo) => {
+                        let repo = Repo::builtin(repo.hooks.clone());
+                        repos.push(Arc::new(repo));
+                    }
                 }
             }
 
