@@ -4,8 +4,8 @@ use anyhow::Result;
 use assert_cmd::assert::OutputAssertExt;
 use assert_fs::fixture::ChildPath;
 use assert_fs::prelude::*;
-use constants::CONFIG_FILE;
 use insta::assert_snapshot;
+use prek_consts::CONFIG_FILE;
 
 use crate::common::{TestContext, cmd_snapshot};
 
@@ -924,13 +924,13 @@ fn quoting_float_like_version_number() -> Result<()> {
     insta::with_settings!(
         { filters => filters.clone() },
         {
-            assert_snapshot!(context.read(CONFIG_FILE), @r#"
+            assert_snapshot!(context.read(CONFIG_FILE), @r"
             repos:
               - repo: [HOME]/test-repos/test-repo
                 rev: '0.50'
                 hooks:
                   - id: test-hook
-            "#);
+            ");
         }
     );
 
