@@ -9,8 +9,8 @@ use assert_fs::fixture::{ChildPath, FileWriteStr, PathChild, PathCreateDir};
 use etcetera::BaseStrategy;
 use rustc_hash::FxHashSet;
 
-use constants::CONFIG_FILE;
-use constants::env_vars::EnvVars;
+use prek_consts::CONFIG_FILE;
+use prek_consts::env_vars::EnvVars;
 
 pub struct TestContext {
     temp_dir: ChildPath,
@@ -34,6 +34,22 @@ impl TestContext {
         let temp_dir = ChildPath::new(root.path()).child("temp");
         fs_err::create_dir_all(&temp_dir).expect("Failed to create test working directory");
 
+        Self::from_root(root, temp_dir)
+    }
+
+    pub fn new_at(path: PathBuf) -> Self {
+        let bucket = Self::test_bucket_dir();
+        fs_err::create_dir_all(&bucket).expect("Failed to create test bucket");
+
+        let root = tempfile::TempDir::new_in(bucket).expect("Failed to create test root directory");
+
+        let temp_dir = ChildPath::new(path);
+        fs_err::create_dir_all(&temp_dir).expect("Failed to create test working directory");
+
+        Self::from_root(root, temp_dir)
+    }
+
+    fn from_root(root: tempfile::TempDir, temp_dir: ChildPath) -> Self {
         let home_dir = ChildPath::new(root.path()).child("home");
         fs_err::create_dir_all(&home_dir).expect("Failed to create test home directory");
 
@@ -50,9 +66,9 @@ impl TestContext {
                 .map(|pattern| (pattern, "[HOME]/".to_string())),
         );
 
-        let current_exe = assert_cmd::cargo::cargo_bin("prek");
+        let current_exe = assert_cmd::cargo::cargo_bin!("prek");
         filters.extend(
-            Self::path_patterns(&current_exe)
+            Self::path_patterns(current_exe)
                 .into_iter()
                 .map(|pattern| (pattern, "[CURRENT_EXE]".to_string())),
         );
@@ -122,7 +138,7 @@ impl TestContext {
             cmd.env(EnvVars::PRE_COMMIT_HOME, &**self.home_dir());
             cmd
         } else {
-            let bin = assert_cmd::cargo::cargo_bin("prek");
+            let bin = assert_cmd::cargo::cargo_bin!("prek");
             let mut cmd = Command::new(bin);
             cmd.current_dir(self.work_dir());
             cmd.env(EnvVars::PREK_HOME, &**self.home_dir());
@@ -308,6 +324,26 @@ impl TestContext {
             .success();
     }
 
+    /// Create a new git branch.
+    pub fn git_branch(&self, branch_name: &str) {
+        Command::new("git")
+            .arg("branch")
+            .arg(branch_name)
+            .current_dir(&self.temp_dir)
+            .assert()
+            .success();
+    }
+
+    /// Switch to a git branch.
+    pub fn git_checkout(&self, branch_name: &str) {
+        Command::new("git")
+            .arg("checkout")
+            .arg(branch_name)
+            .current_dir(&self.temp_dir)
+            .assert()
+            .success();
+    }
+
     /// Write a `.pre-commit-config.yaml` file in the temporary directory.
     pub fn write_pre_commit_config(&self, content: &str) {
         self.temp_dir
@@ -370,18 +406,17 @@ macro_rules! cmd_snapshot {
 pub(crate) use cmd_snapshot;
 
 #[allow(clippy::disallowed_methods)]
-pub(crate) fn remove_bin_from_path(bin: &str) -> anyhow::Result<OsString> {
+pub(crate) fn remove_bin_from_path(bin: &str, path: Option<OsString>) -> anyhow::Result<OsString> {
+    let path = path.unwrap_or(std::env::var_os("PATH").expect("PATH not set"));
     let Ok(dirs) = which::which_all(bin) else {
-        return Ok(std::env::var_os("PATH").expect("PATH environment variable is not set"));
+        return Ok(path);
     };
 
     let dirs: FxHashSet<_> = dirs
         .filter_map(|path| path.parent().map(Path::to_path_buf))
         .collect();
 
-    let current_path = std::env::var("PATH").unwrap_or_default();
-
-    let new_path_entries: Vec<_> = std::env::split_paths(&current_path)
+    let new_path_entries: Vec<_> = std::env::split_paths(&path)
         .filter(|path| !dirs.contains(path.as_path()))
         .collect();
 
