@@ -1,8 +1,8 @@
 use assert_cmd::assert::OutputAssertExt;
 use assert_fs::fixture::{FileWriteStr, PathChild, PathCreateDir};
-use constants::CONFIG_FILE;
-use constants::env_vars::EnvVars;
 use indoc::indoc;
+use prek_consts::CONFIG_FILE;
+use prek_consts::env_vars::EnvVars;
 use std::process::Command;
 
 use crate::common::TestContext;
@@ -44,7 +44,7 @@ fn hook_impl() {
     ----- stderr -----
     "#);
 
-    cmd_snapshot!(context.filters(), commit, @r#"
+    cmd_snapshot!(context.filters(), commit, @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -53,10 +53,11 @@ fn hook_impl() {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       always fail
 
       .pre-commit-config.yaml
-    "#);
+    ");
 }
 
 #[test]
@@ -241,6 +242,7 @@ fn run_worktree() -> anyhow::Result<()> {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       always fail
     ");
 
@@ -306,18 +308,21 @@ fn workspace_hook_impl_root() -> anyhow::Result<()> {
     Test Hook................................................................Passed
     - hook id: test-hook
     - duration: [TIME]
+
       cwd: [TEMP_DIR]/project2
 
     Running hooks for `project3`:
     Test Hook................................................................Passed
     - hook id: test-hook
     - duration: [TIME]
+
       cwd: [TEMP_DIR]/project3
 
     Running hooks for `.`:
     Test Hook................................................................Passed
     - hook id: test-hook
     - duration: [TIME]
+
       cwd: [TEMP_DIR]/
     ");
 
@@ -353,6 +358,8 @@ fn workspace_hook_impl_subdirectory() -> anyhow::Result<()> {
     ----- stdout -----
     prek installed at `../.git/hooks/pre-commit` for workspace `[TEMP_DIR]/project2`
 
+    hint: this hook installed for `[TEMP_DIR]/project2` only; run `prek install` from `[TEMP_DIR]/` to install for the entire repo.
+
     ----- stderr -----
     ");
 
@@ -384,6 +391,7 @@ fn workspace_hook_impl_subdirectory() -> anyhow::Result<()> {
     Test Hook................................................................Passed
     - hook id: test-hook
     - duration: [TIME]
+
       cwd: [TEMP_DIR]/project2
     ");
 
@@ -421,6 +429,8 @@ fn workspace_hook_impl_worktree_subdirectory() -> anyhow::Result<()> {
     ----- stdout -----
     prek installed at `../.git/hooks/pre-commit` for workspace `[TEMP_DIR]/project2`
 
+    hint: this hook installed for `[TEMP_DIR]/project2` only; run `prek install` from `[TEMP_DIR]/` to install for the entire repo.
+
     ----- stderr -----
     ");
 
@@ -507,7 +517,9 @@ fn workspace_hook_impl_no_project_found() -> anyhow::Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: No `.pre-commit-config.yaml` found in the current directory or parent directories in the repository
+    error: No `.pre-commit-config.yaml` found in the current directory or parent directories.
+
+    hint: If you just added one, rerun your command with the `--refresh` flag to rescan the workspace.
     - To temporarily silence this, run `PREK_ALLOW_NO_CONFIG=1 git ...`
     - To permanently silence this, install hooks with the `--allow-missing-config` flag
     - To uninstall hooks, run `prek uninstall`
@@ -573,6 +585,7 @@ fn workspace_hook_impl_no_project_found() -> anyhow::Result<()> {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       fail
 
       .pre-commit-config.yaml
@@ -640,6 +653,7 @@ fn workspace_hook_impl_with_selectors() -> anyhow::Result<()> {
     Test Hook................................................................Passed
     - hook id: test-hook
     - duration: [TIME]
+
       cwd: [TEMP_DIR]/project2
     ");
 
