@@ -7,8 +7,11 @@ mod docker;
 mod docker_image;
 mod fail;
 mod golang;
+mod lua;
 mod node;
 mod pygrep;
 mod python;
+mod ruby;
 mod script;
 mod unimplemented;
+mod unsupported;
