@@ -1,6 +1,6 @@
 use assert_fs::assert::PathAssert;
 use assert_fs::fixture::{FileWriteStr, PathChild};
-use constants::env_vars::EnvVars;
+use prek_consts::env_vars::EnvVars;
 
 use crate::common::{TestContext, cmd_snapshot};
 
@@ -74,30 +74,37 @@ fn language_version() -> anyhow::Result<()> {
     python3..................................................................Passed
     - hook id: python3
     - duration: [TIME]
+
       Hello, World!
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 12)
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 12)
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 12)
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 12)
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 12)
     python3.12...............................................................Passed
     - hook id: python3.12
     - duration: [TIME]
+
       (3, 11)
 
     ----- stderr -----
@@ -150,15 +157,16 @@ fn invalid_version() {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
-    error: Hook `local` is invalid
+    error: Failed to init hooks
+      caused by: Invalid hook `local`
       caused by: Invalid `language_version` value: `invalid-version`
-    "#);
+    ");
 }
 
 /// Request a version that neither can be found nor downloaded.
@@ -200,7 +208,7 @@ fn can_not_download() {
     ----- stderr -----
     error: Failed to install hook `less-than-3.6`
       caused by: Failed to create Python virtual environment
-      caused by: command `create venv` exited with an error:
+      caused by: Command `create venv` exited with an error:
 
     [status]
     exit status: 2
@@ -233,17 +241,18 @@ fn additional_dependencies() {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     local....................................................................Passed
     - hook id: local
     - duration: [TIME]
+
       Hello, world!
 
     ----- stderr -----
-    "#);
+    ");
 }
 
 /// Ensure that stderr from hooks is captured and shown to the user.
@@ -269,17 +278,18 @@ fn hook_stderr() -> anyhow::Result<()> {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     local....................................................................Failed
     - hook id: local
     - exit code: 1
+
       How are you
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -324,21 +334,23 @@ fn pep723_script() -> anyhow::Result<()> {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     other-hook...............................................................Passed
     - hook id: other-hook
     - duration: [TIME]
+
       hello from other-hook
     local....................................................................Passed
     - hook id: local
     - duration: [TIME]
+
       hello world
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
