@@ -16,12 +16,14 @@ fn unimplemented_language() {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     rust-hook............................................(unimplemented yet)Skipped
 
     ----- stderr -----
-    "#);
+    warning: Some hooks were skipped because their languages are unimplemented.
+    We're working hard to support more languages. Check out current support status at https://prek.j178.dev/todo/#language-support-status.
+    ");
 }
