@@ -1,14 +1,15 @@
 use std::path::Path;
 use std::process::Command;
 
-use crate::common::{TestContext, cmd_snapshot};
 use anyhow::Result;
 use assert_cmd::assert::OutputAssertExt;
 use assert_fs::prelude::*;
-use constants::env_vars::EnvVars;
-use constants::{ALT_CONFIG_FILE, CONFIG_FILE};
 use insta::assert_snapshot;
 use predicates::prelude::predicate;
+use prek_consts::env_vars::EnvVars;
+use prek_consts::{ALT_CONFIG_FILE, CONFIG_FILE};
+
+use crate::common::{TestContext, cmd_snapshot};
 
 mod common;
 
@@ -36,7 +37,7 @@ fn run_basic() -> Result<()> {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -44,18 +45,20 @@ fn run_basic() -> Result<()> {
     - hook id: trailing-whitespace
     - exit code: 1
     - files were modified by this hook
+
       Fixing main.py
     fix end of files.........................................................Failed
     - hook id: end-of-file-fixer
     - exit code: 1
     - files were modified by this hook
+
       Fixing valid.json
       Fixing invalid.json
       Fixing main.py
     check json...............................................................Passed
 
     ----- stderr -----
-    "#);
+    ");
 
     context.git_add(".");
 
@@ -71,6 +74,29 @@ fn run_basic() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn run_in_non_git_repo() {
+    let context = TestContext::new();
+
+    let mut filters = context.filters();
+    filters.push((r"exit code: ", "exit status: "));
+
+    cmd_snapshot!(filters, context.run(), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Command `get git root` exited with an error:
+
+    [status]
+    exit status: 128
+
+    [stderr]
+    fatal: not a git repository (or any of the parent directories): .git
+    ");
+}
+
 #[test]
 fn invalid_config() {
     let context = TestContext::new();
@@ -101,15 +127,16 @@ fn invalid_config() {
     "#});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
-    error: Hook `trailing-whitespace` is invalid
-      caused by: Hook specified `additional_dependencies` `dotnet@6` but the language `dotnet` does not support installing dependencies for now
-    "#);
+    error: Failed to init hooks
+      caused by: Invalid hook `trailing-whitespace`
+      caused by: Hook specified `additional_dependencies: dotnet@6` but the language `dotnet` does not support installing dependencies for now
+    ");
 
     context.write_pre_commit_config(indoc::indoc! {r"
         repos:
@@ -123,15 +150,16 @@ fn invalid_config() {
     "});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
-    error: Hook `trailing-whitespace` is invalid
-      caused by: Hook specified `language_version` `6` but the language `fail` does not install an environment
-    "#);
+    error: Failed to init hooks
+      caused by: Invalid hook `trailing-whitespace`
+      caused by: Hook specified `language_version: 6` but the language `fail` does not support toolchain installation for now
+    ");
 }
 
 /// Use same repo multiple times, with same or different revisions.
@@ -163,7 +191,7 @@ fn same_repo() -> Result<()> {
     cwd.child("main.py").write_str(r#"print "abc"  "#)?;
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -171,12 +199,13 @@ fn same_repo() -> Result<()> {
     - hook id: trailing-whitespace
     - exit code: 1
     - files were modified by this hook
+
       Fixing main.py
     trim trailing whitespace.................................................Passed
     trim trailing whitespace.................................................Passed
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -584,22 +613,24 @@ fn files_and_exclude() -> Result<()> {
     "});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     trailing whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       ['file.txt']
     fix end of files.........................................................Failed
     - hook id: end-of-file-fixer
     - exit code: 1
+
       ['file.txt']
     check json...........................................(no files to check)Skipped
 
     ----- stderr -----
-    "#);
+    ");
 
     // Override hook level files and exclude.
     context.write_pre_commit_config(indoc::indoc! {r"
@@ -624,7 +655,7 @@ fn files_and_exclude() -> Result<()> {
     "});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -632,14 +663,16 @@ fn files_and_exclude() -> Result<()> {
     fix end of files.........................................................Failed
     - hook id: end-of-file-fixer
     - exit code: 1
+
       ['file.txt']
     check json...............................................................Failed
     - hook id: check-json
     - exit code: 1
+
       ['file.txt']
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -690,26 +723,29 @@ fn file_types() -> Result<()> {
     "#});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       ['json.json']
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       ['main.py', 'json.json']
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       ['file.txt', '.pre-commit-config.yaml', 'main.py']
     trailing-whitespace..................................(no files to check)Skipped
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -749,21 +785,74 @@ fn fail_fast() {
     "#});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       Fixing files
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       Fixing files
 
     ----- stderr -----
-    "#);
+    ");
+}
+
+/// Test --fail-fast CLI flag stops execution after first failure.
+#[test]
+fn fail_fast_cli_flag() {
+    let context = TestContext::new();
+    context.init_project();
+
+    context.write_pre_commit_config(indoc::indoc! {r#"
+        repos:
+          - repo: local
+            hooks:
+              - id: failing-hook
+                name: failing-hook
+                language: system
+                entry: python3 -c 'print("Failed"); exit(1)'
+                always_run: true
+              - id: passing-hook
+                name: passing-hook
+                language: system
+                entry: python3 -c 'print("Passed")'
+                always_run: true
+    "#});
+    context.git_add(".");
+
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+    failing-hook.............................................................Failed
+    - hook id: failing-hook
+    - exit code: 1
+
+      Failed
+    passing-hook.............................................................Passed
+
+    ----- stderr -----
+    ");
+
+    cmd_snapshot!(context.filters(), context.run().arg("--fail-fast"), @r"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+    failing-hook.............................................................Failed
+    - hook id: failing-hook
+    - exit code: 1
+
+      Failed
+
+    ----- stderr -----
+    ");
 }
 
 /// Run from a subdirectory. File arguments should be fixed to be relative to the root.
@@ -790,29 +879,31 @@ fn subdirectory() -> Result<()> {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run().current_dir(&child).arg("--files").arg("file.txt"), @r#"
+    cmd_snapshot!(context.filters(), context.run().current_dir(&child).arg("--files").arg("file.txt"), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       foo/bar/baz/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
-    cmd_snapshot!(context.filters(), context.run().arg("--cd").arg(&*child).arg("--files").arg("file.txt"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--cd").arg(&*child).arg("--files").arg("file.txt"), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     trailing-whitespace......................................................Failed
     - hook id: trailing-whitespace
     - exit code: 1
+
       foo/bar/baz/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -869,17 +960,18 @@ fn pass_env_vars() {
                 always_run: true
     "#});
 
-    cmd_snapshot!(context.filters(), context.run(), @r###"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     Pass environment.........................................................Failed
     - hook id: env-vars
     - exit code: 1
+
       1
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[test]
@@ -916,20 +1008,20 @@ fn staged_files_only() -> Result<()> {
         .chain([(r"/\d+-\d+.patch", "/[TIME]-[PID].patch")])
         .collect();
 
-    cmd_snapshot!(filters, context.run(), @r#"
+    cmd_snapshot!(filters, context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     trailing-whitespace......................................................Passed
     - hook id: trailing-whitespace
     - duration: [TIME]
+
       Hello, world!
 
     ----- stderr -----
-    Non-staged changes detected, saving to `[HOME]/patches/[TIME]-[PID].patch`
-
+    Unstaged changes detected, stashing unstaged changes to `[HOME]/patches/[TIME]-[PID].patch`
     Restored working tree changes from `[HOME]/patches/[TIME]-[PID].patch`
-    "#);
+    ");
 
     let content = context.read("file.txt");
     assert_snapshot!(content, @"Hello world again!");
@@ -1056,17 +1148,18 @@ fn merge_conflicts() -> Result<()> {
 
     // Fix the conflict and run again.
     context.git_add(".");
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     trailing-whitespace......................................................Passed
     - hook id: trailing-whitespace
     - duration: [TIME]
+
       ['.pre-commit-config.yaml', 'file.txt']
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -1089,17 +1182,18 @@ fn local_python_hook() {
 
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: false
     exit_code: 1
     ----- stdout -----
     local-python-hook........................................................Failed
     - hook id: local-python-hook
     - exit code: 1
+
       Hello, world!
 
     ----- stderr -----
-    "#);
+    ");
 }
 
 /// Invalid `entry`
@@ -1127,7 +1221,7 @@ fn invalid_entry() {
     entry....................................................................
     ----- stderr -----
     error: Failed to run hook `entry`
-      caused by: Hook `entry` is invalid
+      caused by: Invalid hook `entry`
       caused by: Failed to parse entry `"` as commands
     "#);
 }
@@ -1165,8 +1259,9 @@ fn init_nonexistent_repo() {
     ----- stdout -----
 
     ----- stderr -----
-    error: Failed to initialize repo `https://notexistentatallnevergonnahappen.com/nonexistent/repo`
-      caused by: command `git full clone` exited with an error:
+    error: Failed to init hooks
+      caused by: Failed to initialize repo `https://notexistentatallnevergonnahappen.com/nonexistent/repo`
+      caused by: Command `git full clone` exited with an error:
 
     [status]
     exit status: 128
@@ -1225,15 +1320,15 @@ fn types_directory() -> Result<()> {
     ----- stderr -----
     "#);
 
-    cmd_snapshot!(context.filters(), context.run().arg("--files").arg("non-exist-files"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--files").arg("non-exist-files"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory............................................(no files to check)Skipped
 
     ----- stderr -----
-    warning: This file does not exist, it will be ignored: `non-exist-files`
-    "#);
+    warning: This file does not exist and will be ignored: `non-exist-files`
+    ");
     Ok(())
 }
 
@@ -1269,7 +1364,7 @@ fn run_last_commit() -> Result<()> {
 
     // Run with --last-commit should only check files from the last commit
     // This should only process file1.txt and file3.txt, NOT file2.txt
-    cmd_snapshot!(context.filters(), context.run().arg("--last-commit"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--last-commit"), @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -1277,15 +1372,17 @@ fn run_last_commit() -> Result<()> {
     - hook id: trailing-whitespace
     - exit code: 1
     - files were modified by this hook
+
       Fixing file1.txt
     fix end of files.........................................................Failed
     - hook id: end-of-file-fixer
     - exit code: 1
     - files were modified by this hook
+
       Fixing file3.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     // Now reset the files to their problematic state for comparison
     cwd.child("file1.txt").write_str("Hello, world!   \n")?; // trailing whitespace
@@ -1293,7 +1390,7 @@ fn run_last_commit() -> Result<()> {
 
     // Run with --all-files should check ALL files including file2.txt
     // This demonstrates that file2.txt was indeed filtered out in the previous test
-    cmd_snapshot!(context.filters(), context.run().arg("--all-files"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--all-files"), @r"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -1301,16 +1398,18 @@ fn run_last_commit() -> Result<()> {
     - hook id: trailing-whitespace
     - exit code: 1
     - files were modified by this hook
+
       Fixing file1.txt
       Fixing file2.txt
     fix end of files.........................................................Failed
     - hook id: end-of-file-fixer
     - exit code: 1
     - files were modified by this hook
+
       Fixing file3.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -1336,17 +1435,18 @@ fn run_multiple_files() -> Result<()> {
     cwd.child("file2.txt").write_str("Hello, world!")?;
     context.git_add(".");
     // `--files` with multiple files
-    cmd_snapshot!(context.filters(), context.run().arg("--files").arg("file1.txt").arg("file2.txt"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--files").arg("file1.txt").arg("file2.txt"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     multiple-files...........................................................Passed
     - hook id: multiple-files
     - duration: [TIME]
+
       file2.txt file1.txt
 
     ----- stderr -----
-    "#);
+    ");
     Ok(())
 }
 
@@ -1367,17 +1467,18 @@ fn run_no_files() {
     "});
     context.git_add(".");
     // `--files` with no files
-    cmd_snapshot!(context.filters(), context.run().arg("--files"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--files"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     no-files.................................................................Passed
     - hook id: no-files
     - duration: [TIME]
+
       .pre-commit-config.yaml
 
     ----- stderr -----
-    "#);
+    ");
 }
 
 /// Test `prek run --directory` flags.
@@ -1404,43 +1505,46 @@ fn run_directory() -> Result<()> {
     context.git_add(".");
 
     // one `--directory`
-    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     // repeated `--directory`
-    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--directory").arg("dir1"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--directory").arg("dir1"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     // multiple `--directory`
-    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--directory").arg("dir2"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--directory").arg("dir2"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir2/file.txt dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     // non-existing directory
     cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("non-existing-dir"), @r#"
@@ -1453,53 +1557,57 @@ fn run_directory() -> Result<()> {
     "#);
 
     // `--directory` with `--files`
-    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--files").arg("dir1/file.txt"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--files").arg("dir1/file.txt"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir1/file.txt
 
     ----- stderr -----
-    "#);
-    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--files").arg("dir2/file.txt"), @r#"
+    ");
+    cmd_snapshot!(context.filters(), context.run().arg("--directory").arg("dir1").arg("--files").arg("dir2/file.txt"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir2/file.txt dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     // run `--directory` inside a subdirectory
-    cmd_snapshot!(context.filters(), context.run().current_dir(cwd.join("dir1")).arg("--directory").arg("."), @r#"
+    cmd_snapshot!(context.filters(), context.run().current_dir(cwd.join("dir1")).arg("--directory").arg("."), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
-    cmd_snapshot!(context.filters(), context.run().arg("--cd").arg("dir1").arg("--directory").arg("."), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--cd").arg("dir1").arg("--directory").arg("."), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     directory................................................................Passed
     - hook id: directory
     - duration: [TIME]
+
       dir1/file.txt
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -1573,30 +1681,32 @@ fn color() -> Result<()> {
 
     // Run default. In integration tests, we don't have a TTY.
     // So this prints without color.
-    cmd_snapshot!(context.filters(), context.run(), @r#"
-  success: true
-  exit_code: 0
-  ----- stdout -----
-  color....................................................................Passed
-  - hook id: color
-  - duration: [TIME]
-    Hello, world!
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    color....................................................................Passed
+    - hook id: color
+    - duration: [TIME]
 
-  ----- stderr -----
-  "#);
+      Hello, world!
+
+    ----- stderr -----
+    ");
 
     // Force color output
-    cmd_snapshot!(context.filters(), context.run().arg("--color=always"), @r#"
+    cmd_snapshot!(context.filters(), context.run().arg("--color=always"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     color....................................................................[42mPassed[49m
     [2m- hook id: color[0m
     [2m- duration: [TIME][0m
-    [2m  [1;32mHello, world![0m[0m
+
+      [1;32mHello, world![0m
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -1630,17 +1740,18 @@ fn shebang_script() -> Result<()> {
     "});
     context.git_add(".");
 
-    cmd_snapshot!(context.filters(), context.run(), @r#"
+    cmd_snapshot!(context.filters(), context.run(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
     shebang-script...........................................................Passed
     - hook id: shebang-script
     - duration: [TIME]
+
       Hello, world!
 
     ----- stderr -----
-    "#);
+    ");
 
     Ok(())
 }
@@ -1698,7 +1809,7 @@ fn git_commit_a() -> Result<()> {
         .chain([(r"\[master \w{7}\]", r"[master COMMIT]")])
         .collect::<Vec<_>>();
 
-    cmd_snapshot!(filters, commit, @r#"
+    cmd_snapshot!(filters, commit, @r"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1709,8 +1820,9 @@ fn git_commit_a() -> Result<()> {
     echo.....................................................................Passed
     - hook id: echo
     - duration: [TIME]
+
       file.txt
-    "#);
+    ");
 
     Ok(())
 }
@@ -1793,6 +1905,7 @@ fn selectors_completion() -> Result<()> {
     --last-commit	Run hooks against the last commit. Equivalent to `--from-ref HEAD~1 --to-ref HEAD`
     --hook-stage	The stage during which the hook is fired
     --show-diff-on-failure	When hooks fail, run `git diff` directly afterward
+    --fail-fast	Stop running hooks after the first failure
     --dry-run	Do not run the hooks, but print the hooks that would have been run
     --config	Path to alternate config file
     --cd	Change to directory before running
@@ -1905,6 +2018,7 @@ fn reuse_env() -> Result<()> {
     flake8...................................................................Failed
     - hook id: flake8
     - exit code: 1
+
       err.py:1:1: EM101 Exceptions must not use a string literal; assign to a variable first
 
     ----- stderr -----
@@ -1958,6 +2072,7 @@ fn dry_run() {
     fail.....................................................................Dry Run
     - hook id: fail
     - duration: [TIME]
+
       `fail` would be run on 1 files:
       - .pre-commit-config.yaml
 
@@ -1992,6 +2107,7 @@ fn alternate_config_file() -> Result<()> {
     local-python-hook........................................................Passed
     - hook id: local-python-hook
     - duration: [TIME]
+
       Hello, world!
 
     ----- stderr -----
@@ -2018,6 +2134,7 @@ fn alternate_config_file() -> Result<()> {
     local-python-hook........................................................Passed
     - hook id: local-python-hook
     - duration: [TIME]
+
       Hello, world!
 
     ----- stderr -----
@@ -2205,6 +2322,7 @@ fn run_quiet() {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       fail
 
       .pre-commit-config.yaml
@@ -2246,6 +2364,7 @@ fn run_log_file() {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       fail
 
       .pre-commit-config.yaml
@@ -2265,6 +2384,7 @@ fn run_log_file() {
     fail.....................................................................Failed
     - hook id: fail
     - exit code: 1
+
       fail
 
       .pre-commit-config.yaml
@@ -2276,3 +2396,107 @@ fn run_log_file() {
         .child("log")
         .assert(predicate::path::exists());
 }
+
+/// Test `language_version: system` works and disables downloading.
+#[test]
+fn system_language_version() {
+    if !EnvVars::is_set(EnvVars::CI) {
+        // Skip when not running in CI, as we may not have toolchains installed locally.
+        return;
+    }
+
+    let context = TestContext::new();
+    context.init_project();
+    context.write_pre_commit_config(indoc::indoc! {r"
+        repos:
+          - repo: local
+            hooks:
+              - id: system-node
+                name: system-node
+                language: node
+                language_version: system
+                entry: node -v
+                pass_filenames: false
+              - id: system-go
+                name: system-go
+                language: golang
+                language_version: system
+                entry: go version
+                pass_filenames: false
+   "});
+    context.git_add(".");
+
+    // Go and Node can't be found, `system` must fail.
+    cmd_snapshot!(
+        context.filters(),
+        context.run()
+        .arg("system-node")
+        .env(EnvVars::PREK_INTERNAL__GO_BINARY_NAME, "go-never-exist")
+        .env(EnvVars::PREK_INTERNAL__NODE_BINARY_NAME, "node-never-exist"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to install hook `system-node`
+      caused by: Failed to install node
+      caused by: No suitable system Node version found and downloads are disabled
+    ");
+
+    cmd_snapshot!(
+        context.filters(),
+        context.run()
+        .arg("system-go")
+        .env(EnvVars::PREK_INTERNAL__GO_BINARY_NAME, "go-never-exist")
+        .env(EnvVars::PREK_INTERNAL__NODE_BINARY_NAME, "node-never-exist"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to install hook `system-go`
+      caused by: Failed to install go
+      caused by: No suitable system Go version found and downloads are disabled
+    ");
+
+    // When Go and Node are available, hooks pass.
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    system-node..............................................................Passed
+    system-go................................................................Passed
+
+    ----- stderr -----
+    ");
+}
+
+/// Tests that empty `entry` field.
+#[test]
+fn empty_entry() {
+    let context = TestContext::new();
+    context.init_project();
+    context.write_pre_commit_config(indoc::indoc! {r"
+        repos:
+          - repo: local
+            hooks:
+              - id: local
+                name: local
+                language: python
+                entry: ''
+                pass_filenames: false
+   "});
+    context.git_add(".");
+
+    // Go and Node can't be found, `system` must fail.
+    cmd_snapshot!(context.filters(), context.run(), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+    local....................................................................
+    ----- stderr -----
+    error: Failed to run hook `local`
+      caused by: Invalid hook `local`
+      caused by: Failed to parse entry: entry is empty
+    ");
+}
